From 27edf28be2772229a7974a007313ea30d92c3ffd Mon Sep 17 00:00:00 2001
From: tpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>
Date: Wed, 10 Aug 2011 22:19:39 +0000
Subject: rename the following methods: tqparent parent tqmask mask

git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdemultimedia@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
---
 arts/builder/TODO                                  |  2 +-
 arts/builder/execdlg.cpp                           |  4 +-
 arts/builder/execdlg.h                             |  2 +-
 arts/builder/interfacedlg.cpp                      |  2 +-
 arts/builder/interfacedlg.h                        |  2 +-
 arts/builder/menumaker.cpp                         |  6 +--
 arts/builder/menumaker.h                           |  2 +-
 arts/builder/mwidget.cpp                           |  4 +-
 arts/builder/mwidget.h                             |  2 +-
 arts/builder/portposdlg.cpp                        |  2 +-
 arts/builder/portposdlg.h                          |  2 +-
 arts/builder/propertypanel.cpp                     |  4 +-
 arts/builder/propertypanel.h                       |  2 +-
 arts/builder/qttableview.cpp                       | 10 ++--
 arts/builder/qttableview.h                         |  2 +-
 arts/builder/retrievedlg.cpp                       |  2 +-
 arts/builder/retrievedlg.h                         |  2 +-
 arts/examples/instrument_flexible_slide_GUI.arts   | 14 +++---
 arts/examples/instrument_moog_vcf_tune_GUI.arts    | 10 ++--
 arts/examples/mixer_element_eq.arts                |  4 +-
 arts/examples/mixer_element_eqfx.arts              | 20 ++++----
 arts/examples/mixer_element_simple.arts            |  6 +--
 arts/examples/template_Instrument_GUI.arts         |  4 +-
 arts/examples/template_Mixer_Element.arts          |  6 +--
 arts/gui/common/artsgui.idl                        | 22 ++++-----
 arts/gui/kde/artstestgui.cpp                       | 10 ++--
 arts/gui/kde/kartswidget.cpp                       | 16 +++----
 arts/gui/kde/kartswidget.h                         |  6 +--
 arts/gui/kde/kbutton_impl.cpp                      |  4 +-
 arts/gui/kde/kbutton_impl.h                        |  2 +-
 arts/gui/kde/kcombobox_impl.h                      |  2 +-
 arts/gui/kde/kfader.cpp                            |  8 ++--
 arts/gui/kde/kfader.h                              |  4 +-
 arts/gui/kde/kfader_impl.h                         |  2 +-
 arts/gui/kde/kframe_impl.h                         |  2 +-
 arts/gui/kde/kgraph.cpp                            |  4 +-
 arts/gui/kde/kgraph.h                              |  2 +-
 arts/gui/kde/kgraph_impl.h                         |  2 +-
 arts/gui/kde/klabel_impl.h                         |  2 +-
 arts/gui/kde/klayoutbox_impl.cpp                   |  4 +-
 arts/gui/kde/klevelmeter_firebars.cpp              |  4 +-
 arts/gui/kde/klevelmeter_impl.cpp                  |  4 +-
 arts/gui/kde/klevelmeter_linebars.cpp              |  4 +-
 arts/gui/kde/klevelmeter_normalbars.cpp            |  4 +-
 arts/gui/kde/klevelmeter_normalbars.h              |  2 +-
 arts/gui/kde/klevelmeter_small.cpp                 |  4 +-
 arts/gui/kde/klineedit_impl.h                      |  2 +-
 arts/gui/kde/kpopupbox_impl.cpp                    |  4 +-
 arts/gui/kde/kpopupbox_private.h                   |  6 +--
 arts/gui/kde/kpoti.cpp                             | 28 +++++------
 arts/gui/kde/kpoti.h                               |  4 +-
 arts/gui/kde/kspinbox_impl.h                       |  2 +-
 arts/gui/kde/kwidget_impl.cpp                      | 12 ++---
 arts/gui/kde/kwidget_impl.h                        |  4 +-
 arts/modules/README.environments                   |  2 +-
 arts/modules/common/artsmodulescommon.idl          |  4 +-
 arts/modules/common/effectrackslot_impl.cc         | 16 +++----
 arts/modules/common/env_effectrackitem_impl.cc     |  6 +--
 arts/modules/common/env_instrumentitem_impl.cc     |  2 +-
 arts/modules/common/env_item_impl.cc               |  2 +-
 arts/modules/common/env_item_impl.h                |  2 +-
 arts/modules/common/env_mixeritem_impl.cc          | 22 ++++-----
 arts/modules/effects/fivebandmonocomplexeq_impl.cc | 20 ++++----
 arts/modules/effects/freeverbguifactory_impl.cc    | 10 ++--
 .../modules/effects/kstereovolumecontrolgui_impl.h |  2 +-
 .../effects/synth_stereo_fir_equalizer_impl.cc     |  4 +-
 .../modules/effects/voiceremovalguifactory_impl.cc |  4 +-
 arts/modules/synth/synth_cdelay_impl.cc            | 20 ++++----
 arts/modules/synth/synth_delay_impl.cc             | 20 ++++----
 arts/runtime/artsbuilder.idl                       | 12 ++---
 arts/runtime/structurebuilder_impl.cc              | 12 ++---
 arts/runtime/structures_impl.cc                    | 56 +++++++++++-----------
 arts/tools/artsactions.cpp                         |  4 +-
 arts/tools/artsactions.h                           |  2 +-
 arts/tools/artscontrolapplet.cpp                   |  8 ++--
 arts/tools/artscontrolapplet.h                     |  2 +-
 arts/tools/artscontrolapplet_private.h             |  8 ++--
 arts/tools/audiomanager.cpp                        | 18 +++----
 arts/tools/audiomanager.h                          |  2 +-
 arts/tools/choosebusdlg.cpp                        |  4 +-
 arts/tools/choosebusdlg.h                          |  2 +-
 arts/tools/environmentview.cpp                     |  2 +-
 arts/tools/fftscopeview.cpp                        |  4 +-
 arts/tools/levelmeters.cpp                         | 16 +++----
 arts/tools/levelmeters.h                           | 14 +++---
 arts/tools/main.cpp                                |  2 +-
 arts/tools/main.h                                  |  2 +-
 arts/tools/mediatypesview.cpp                      |  2 +-
 arts/tools/midiinstdlg.cpp                         |  4 +-
 arts/tools/midiinstdlg.h                           |  2 +-
 arts/tools/midimanagerview.cpp                     |  2 +-
 arts/tools/midiportdlg.cpp                         |  2 +-
 arts/tools/midiportdlg.h                           |  2 +-
 arts/tools/statusview.cpp                          |  4 +-
 arts/tools/templateview.cpp                        |  2 +-
 95 files changed, 309 insertions(+), 309 deletions(-)

(limited to 'arts')

diff --git a/arts/builder/TODO b/arts/builder/TODO
index 0c8a0859..8b962aa5 100644
--- a/arts/builder/TODO
+++ b/arts/builder/TODO
@@ -44,7 +44,7 @@ Wishlist for the artsbuilder app:
 - make _changed Q_SIGNALS visible so you can connect the value_changed of a
   poti to the frequency of a filter
 
-- make it possible to edit tqparent property of widgets (i.e. to insert one
+- make it possible to edit parent property of widgets (i.e. to insert one
   widget into another)
 
 - add structure property dialog with structure meta information, at least
diff --git a/arts/builder/execdlg.cpp b/arts/builder/execdlg.cpp
index bad531aa..790691e8 100644
--- a/arts/builder/execdlg.cpp
+++ b/arts/builder/execdlg.cpp
@@ -45,8 +45,8 @@ static void min_size(TQWidget *w) {
 }
 #endif
 
-ExecDlg::ExecDlg(TQWidget *tqparent, ExecutableStructure *structure)
-		:TQDialog(tqparent,"X")
+ExecDlg::ExecDlg(TQWidget *parent, ExecutableStructure *structure)
+		:TQDialog(parent,"X")
 /*, TRUE)*/
 {
 	this->structure = structure;
diff --git a/arts/builder/execdlg.h b/arts/builder/execdlg.h
index d916a4ff..61348c0f 100644
--- a/arts/builder/execdlg.h
+++ b/arts/builder/execdlg.h
@@ -40,7 +40,7 @@ public:
 
 	void start();
 	void done(int r);
-	ExecDlg(TQWidget *tqparent, ExecutableStructure *structure);
+	ExecDlg(TQWidget *parent, ExecutableStructure *structure);
 			
 protected slots:
 	void updateCpuUsage();
diff --git a/arts/builder/interfacedlg.cpp b/arts/builder/interfacedlg.cpp
index 9680fc7e..3b4d455a 100644
--- a/arts/builder/interfacedlg.cpp
+++ b/arts/builder/interfacedlg.cpp
@@ -41,7 +41,7 @@
 
 using namespace std;
 
-InterfaceDlg::InterfaceDlg(TQWidget *tqparent) :TQDialog(tqparent,"Props", TRUE)
+InterfaceDlg::InterfaceDlg(TQWidget *parent) :TQDialog(parent,"Props", TRUE)
 {
 	setCaption(i18n("aRts: Structureport View"));
 
diff --git a/arts/builder/interfacedlg.h b/arts/builder/interfacedlg.h
index 235245a7..09cf5659 100644
--- a/arts/builder/interfacedlg.h
+++ b/arts/builder/interfacedlg.h
@@ -37,7 +37,7 @@ protected:
 	TQListBox *listbox;
 
 public:
-	InterfaceDlg(TQWidget *tqparent);
+	InterfaceDlg(TQWidget *parent);
 
 	std::string interfaceName();
 	void update(const std::string& interface, const std::string& indent);
diff --git a/arts/builder/menumaker.cpp b/arts/builder/menumaker.cpp
index 38f28ace..2aed8401 100644
--- a/arts/builder/menumaker.cpp
+++ b/arts/builder/menumaker.cpp
@@ -5,11 +5,11 @@
 
 using namespace std;
 
-MenuEntry::MenuEntry(MenuMaker *menumaker, KActionMenu *tqparent, const char *text)
+MenuEntry::MenuEntry(MenuMaker *menumaker, KActionMenu *parent, const char *text)
 	: menumaker(menumaker), text(text)
 {
 	action = new KAction(TQString::fromLocal8Bit(text));
-	tqparent->insert(action);
+	parent->insert(action);
 	connect(action, TQT_SIGNAL(activated()), this, TQT_SLOT(activated()));
 }
 
@@ -95,7 +95,7 @@ void MenuMaker::addCategory(const TQString& name, const char *prefix)
 		/* 000 */
 		/*connect(newMenu,TQT_SIGNAL(activated(int)),this,TQT_SLOT(menuactivated(int)));
 		pc->menu()->insertItem(catname(name).c_str(), newMenu, CAT_MAGIC_ID);*/
-		arts_debug("inserting a menu called '%s' in the tqparent menu '%s'",
+		arts_debug("inserting a menu called '%s' in the parent menu '%s'",
 			catname(name).local8Bit().data(),pc->name().local8Bit().data());
 		categories.push_back(new MenuCategory(name,prefix,newMenu));
 	}
diff --git a/arts/builder/menumaker.h b/arts/builder/menumaker.h
index 583854f6..3cb93fe3 100644
--- a/arts/builder/menumaker.h
+++ b/arts/builder/menumaker.h
@@ -19,7 +19,7 @@ protected:
 	TQCString text;
 
 public:
-	MenuEntry(MenuMaker *menumaker, KActionMenu *tqparent, const char *text);
+	MenuEntry(MenuMaker *menumaker, KActionMenu *parent, const char *text);
 
 public slots:
 	void activated();
diff --git a/arts/builder/mwidget.cpp b/arts/builder/mwidget.cpp
index 5ab19fe7..8b2aeed8 100644
--- a/arts/builder/mwidget.cpp
+++ b/arts/builder/mwidget.cpp
@@ -608,8 +608,8 @@ void ModuleWidget::autoRedrawRouter()
 	if(autorouter->needRedraw()) redrawAll();
 }
 
-ModuleWidget::ModuleWidget(Structure *structure, TQWidget *tqparent, const char *name, WFlags f)
-	: QtTableView( tqparent, name, f),
+ModuleWidget::ModuleWidget(Structure *structure, TQWidget *parent, const char *name, WFlags f)
+	: QtTableView( parent, name, f),
 	  updateDepth( 0 ),
 	  activeTool( 0L ),
 	  structure( structure ),
diff --git a/arts/builder/mwidget.h b/arts/builder/mwidget.h
index b3b41b78..cc6dbfca 100644
--- a/arts/builder/mwidget.h
+++ b/arts/builder/mwidget.h
@@ -109,7 +109,7 @@ public:
 	TQPoint componentPos(const StructureComponent *component) const;
 	TQPoint portPos(const ModulePort *port) const;
 
-	ModuleWidget( Structure *structure, TQWidget *tqparent = 0,
+	ModuleWidget( Structure *structure, TQWidget *parent = 0,
 				  const char *name = 0, WFlags f = 0);
 
 	~ModuleWidget();
diff --git a/arts/builder/portposdlg.cpp b/arts/builder/portposdlg.cpp
index ecd877c9..63f2546c 100644
--- a/arts/builder/portposdlg.cpp
+++ b/arts/builder/portposdlg.cpp
@@ -40,7 +40,7 @@
 
 using namespace std;
 
-PortPosDlg::PortPosDlg(TQWidget *tqparent, Structure *structure) :TQDialog(tqparent,"Props", TRUE)
+PortPosDlg::PortPosDlg(TQWidget *parent, Structure *structure) :TQDialog(parent,"Props", TRUE)
 {
 	this->structure = structure;
 
diff --git a/arts/builder/portposdlg.h b/arts/builder/portposdlg.h
index aa61bad1..70d39338 100644
--- a/arts/builder/portposdlg.h
+++ b/arts/builder/portposdlg.h
@@ -39,7 +39,7 @@ protected:
 
 	std::vector<StructurePort *> listports;
 public:
-	PortPosDlg(TQWidget *tqparent, Structure *structure);
+	PortPosDlg(TQWidget *parent, Structure *structure);
 
 	void update();
 public slots:
diff --git a/arts/builder/propertypanel.cpp b/arts/builder/propertypanel.cpp
index ed3df208..df76588a 100644
--- a/arts/builder/propertypanel.cpp
+++ b/arts/builder/propertypanel.cpp
@@ -36,8 +36,8 @@
 
 #include <arts/debug.h>
 
-PropertyPanel::PropertyPanel( TQWidget* tqparent, const char* name, WFlags fl )
-	: PropertyPanelBase( tqparent, name, fl ),
+PropertyPanel::PropertyPanel( TQWidget* parent, const char* name, WFlags fl )
+	: PropertyPanelBase( parent, name, fl ),
 	  component(0L),
 	  port(0L)
 {
diff --git a/arts/builder/propertypanel.h b/arts/builder/propertypanel.h
index 07ce3f90..cf34fe65 100644
--- a/arts/builder/propertypanel.h
+++ b/arts/builder/propertypanel.h
@@ -36,7 +36,7 @@ class PropertyPanel: public PropertyPanelBase
   TQ_OBJECT
 	
 public:
-	PropertyPanel( TQWidget* tqparent = 0, const char* name = 0, WFlags fl = 0 );
+	PropertyPanel( TQWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
 
 public slots:
 	void setSelectedComponent( StructureComponent *component );
diff --git a/arts/builder/qttableview.cpp b/arts/builder/qttableview.cpp
index bfb5539c..f8716b44 100644
--- a/arts/builder/qttableview.cpp
+++ b/arts/builder/qttableview.cpp
@@ -45,8 +45,8 @@ public:
     void paintEvent( TQPaintEvent * );
 };
 
-TQCornerSquare::TQCornerSquare( TQWidget *tqparent, const char *name )
-	: TQWidget( tqparent, name )
+TQCornerSquare::TQCornerSquare( TQWidget *parent, const char *name )
+	: TQWidget( parent, name )
 {
 }
 
@@ -125,7 +125,7 @@ void TQCornerSquare::paintEvent( TQPaintEvent * )
 
 
 /*!
-  Constructs a table view.  The \a tqparent, \a name and \f arguments
+  Constructs a table view.  The \a parent, \a name and \f arguments
   are passed to the TQFrame constructor.
 
   The \link setTableFlags() table flags\endlink are all cleared (set to 0).
@@ -144,8 +144,8 @@ void TQCornerSquare::paintEvent( TQPaintEvent * )
 
 */
 
-QtTableView::QtTableView( TQWidget *tqparent, const char *name, WFlags f )
-    : TQFrame( tqparent, name, f )
+QtTableView::QtTableView( TQWidget *parent, const char *name, WFlags f )
+    : TQFrame( parent, name, f )
 {
     nRows		 = nCols      = 0;	// zero rows/cols
     xCellOffs		 = yCellOffs  = 0;	// zero offset
diff --git a/arts/builder/qttableview.h b/arts/builder/qttableview.h
index a6e868b6..7d4f14e2 100644
--- a/arts/builder/qttableview.h
+++ b/arts/builder/qttableview.h
@@ -37,7 +37,7 @@ public:
     void	tqrepaint( const TQRect &, bool erase=TRUE );
 
 protected:
-    QtTableView( TQWidget *tqparent=0, const char *name=0, WFlags f=0 );
+    QtTableView( TQWidget *parent=0, const char *name=0, WFlags f=0 );
    ~QtTableView();
 
     int		numRows()	const;
diff --git a/arts/builder/retrievedlg.cpp b/arts/builder/retrievedlg.cpp
index c54cbabd..5b738471 100644
--- a/arts/builder/retrievedlg.cpp
+++ b/arts/builder/retrievedlg.cpp
@@ -40,7 +40,7 @@ static void min_size(TQWidget *w) {
   w->setMinimumSize(w->tqsizeHint());
 }
 
-RetrieveDlg::RetrieveDlg(TQWidget *tqparent) :TQDialog(tqparent,"X", TRUE)
+RetrieveDlg::RetrieveDlg(TQWidget *parent) :TQDialog(parent,"X", TRUE)
 {
 	setCaption(i18n("Retrieve Structure From Server"));
 
diff --git a/arts/builder/retrievedlg.h b/arts/builder/retrievedlg.h
index 3ffa57ee..51649c4f 100644
--- a/arts/builder/retrievedlg.h
+++ b/arts/builder/retrievedlg.h
@@ -38,7 +38,7 @@ class RetrieveDlg :public TQDialog {
   TQ_OBJECT
 	TQListBox *listbox;
 public:
-	RetrieveDlg(TQWidget *tqparent);
+	RetrieveDlg(TQWidget *parent);
 	TQString result();
 public slots:
 	void help();
diff --git a/arts/examples/instrument_flexible_slide_GUI.arts b/arts/examples/instrument_flexible_slide_GUI.arts
index 92523fa0..3b0f0bca 100644
--- a/arts/examples/instrument_flexible_slide_GUI.arts
+++ b/arts/examples/instrument_flexible_slide_GUI.arts
@@ -8,7 +8,7 @@ module=Arts::Poti
   {
     id=1
   }
-  port=tqparent
+  port=parent
   {
     id=2
   }
@@ -71,7 +71,7 @@ module=Arts::Widget
   {
     id=14
   }
-  port=tqparent
+  port=parent
   {
     id=15
   }
@@ -110,7 +110,7 @@ module=Arts::Poti
   {
     id=22
   }
-  port=tqparent
+  port=parent
   {
     id=23
   }
@@ -169,7 +169,7 @@ module=Arts::Poti
   {
     id=35
   }
-  port=tqparent
+  port=parent
   {
     id=36
   }
@@ -230,7 +230,7 @@ module=Arts::Poti
   {
     id=48
   }
-  port=tqparent
+  port=parent
   {
     id=49
   }
@@ -291,7 +291,7 @@ module=Arts::Poti
   {
     id=61
   }
-  port=tqparent
+  port=parent
   {
     id=62
   }
@@ -345,7 +345,7 @@ module=Arts::Poti
 }
 structureport
 {
-  name=tqparent
+  name=parent
   x=2
   y=1
   position=0
diff --git a/arts/examples/instrument_moog_vcf_tune_GUI.arts b/arts/examples/instrument_moog_vcf_tune_GUI.arts
index 0aff72a8..6db62f60 100644
--- a/arts/examples/instrument_moog_vcf_tune_GUI.arts
+++ b/arts/examples/instrument_moog_vcf_tune_GUI.arts
@@ -8,7 +8,7 @@ module=Arts::Widget
   {
     id=1
   }
-  port=tqparent
+  port=parent
   {
     id=2
   }
@@ -47,7 +47,7 @@ module=Arts::Poti
   {
     id=9
   }
-  port=tqparent
+  port=parent
   {
     id=10
   }
@@ -110,7 +110,7 @@ module=Arts::Poti
   {
     id=22
   }
-  port=tqparent
+  port=parent
   {
     id=23
   }
@@ -173,7 +173,7 @@ module=Arts::Poti
   {
     id=35
   }
-  port=tqparent
+  port=parent
   {
     id=36
   }
@@ -229,7 +229,7 @@ module=Arts::Poti
 }
 structureport
 {
-  name=tqparent
+  name=parent
   x=2
   y=1
   position=0
diff --git a/arts/examples/mixer_element_eq.arts b/arts/examples/mixer_element_eq.arts
index c798166f..6123bb24 100644
--- a/arts/examples/mixer_element_eq.arts
+++ b/arts/examples/mixer_element_eq.arts
@@ -8,7 +8,7 @@ module=Arts::Widget
   {
     id=1
   }
-  port=tqparent
+  port=parent
   {
     id=2
   }
@@ -550,7 +550,7 @@ structureport
 }
 structureport
 {
-  name=tqparent
+  name=parent
   x=7
   y=0
   position=0
diff --git a/arts/examples/mixer_element_eqfx.arts b/arts/examples/mixer_element_eqfx.arts
index 8bde0f61..b7248fcb 100644
--- a/arts/examples/mixer_element_eqfx.arts
+++ b/arts/examples/mixer_element_eqfx.arts
@@ -4,7 +4,7 @@ module=Gui_SUB_PANEL
   id=147
   x=6
   y=1
-  port=tqparent
+  port=parent
   {
     id=148
     connect_to=279
@@ -52,7 +52,7 @@ module=Gui_POTI
   id=155
   x=0
   y=3
-  port=tqparent
+  port=parent
   {
     id=156
     connect_to=154
@@ -193,7 +193,7 @@ module=Gui_LABEL
   id=182
   x=13
   y=4
-  port=tqparent
+  port=parent
   {
     id=183
     connect_to=154
@@ -313,7 +313,7 @@ module=Gui_POTI
   id=205
   x=14
   y=9
-  port=tqparent
+  port=parent
   {
     id=206
     connect_to=154
@@ -365,7 +365,7 @@ module=Gui_POTI
   id=215
   x=14
   y=11
-  port=tqparent
+  port=parent
   {
     id=216
     connect_to=154
@@ -417,7 +417,7 @@ module=Gui_POTI
   id=225
   x=14
   y=7
-  port=tqparent
+  port=parent
   {
     id=226
     connect_to=154
@@ -469,7 +469,7 @@ module=Gui_POTI
   id=235
   x=14
   y=13
-  port=tqparent
+  port=parent
   {
     id=236
     connect_to=154
@@ -521,7 +521,7 @@ module=Gui_POTI
   id=245
   x=14
   y=15
-  port=tqparent
+  port=parent
   {
     id=246
     connect_to=154
@@ -573,7 +573,7 @@ module=Gui_POTI
   id=255
   x=14
   y=17
-  port=tqparent
+  port=parent
   {
     id=256
     connect_to=154
@@ -722,7 +722,7 @@ structureport
 }
 structureport
 {
-  name=tqparent
+  name=parent
   x=7
   y=0
   position=0
diff --git a/arts/examples/mixer_element_simple.arts b/arts/examples/mixer_element_simple.arts
index be572011..01246090 100644
--- a/arts/examples/mixer_element_simple.arts
+++ b/arts/examples/mixer_element_simple.arts
@@ -8,7 +8,7 @@ module=Arts::Widget
   {
     id=1
   }
-  port=tqparent
+  port=parent
   {
     id=2
   }
@@ -47,7 +47,7 @@ module=Arts::Poti
   {
     id=9
   }
-  port=tqparent
+  port=parent
   {
     id=10
   }
@@ -218,7 +218,7 @@ structureport
 }
 structureport
 {
-  name=tqparent
+  name=parent
   x=7
   y=0
   position=0
diff --git a/arts/examples/template_Instrument_GUI.arts b/arts/examples/template_Instrument_GUI.arts
index 751d4cc4..67db385e 100644
--- a/arts/examples/template_Instrument_GUI.arts
+++ b/arts/examples/template_Instrument_GUI.arts
@@ -8,7 +8,7 @@ module=Arts::Widget
   {
     id=1
   }
-  port=tqparent
+  port=parent
   {
     id=2
   }
@@ -40,7 +40,7 @@ module=Arts::Widget
 }
 structureport
 {
-  name=tqparent
+  name=parent
   x=2
   y=1
   position=0
diff --git a/arts/examples/template_Mixer_Element.arts b/arts/examples/template_Mixer_Element.arts
index caa885ed..40c3e63c 100644
--- a/arts/examples/template_Mixer_Element.arts
+++ b/arts/examples/template_Mixer_Element.arts
@@ -4,7 +4,7 @@ module=Gui_SUB_PANEL
   id=0
   x=0
   y=1
-  port=tqparent
+  port=parent
   {
     id=1
     connect_to=26
@@ -88,7 +88,7 @@ module=Gui_LABEL
   id=17
   x=6
   y=4
-  port=tqparent
+  port=parent
   {
     id=18
     connect_to=7
@@ -158,7 +158,7 @@ structureport
 }
 structureport
 {
-  name=tqparent
+  name=parent
   x=1
   y=0
   position=0
diff --git a/arts/gui/common/artsgui.idl b/arts/gui/common/artsgui.idl
index de6da9e7..c88dd3f1 100644
--- a/arts/gui/common/artsgui.idl
+++ b/arts/gui/common/artsgui.idl
@@ -48,7 +48,7 @@ module Arts {
 	interface Widget {
 		readonly attribute long widgetID;
 
-		attribute Widget tqparent;
+		attribute Widget parent;
 		attribute long x,y,width,height;
 		attribute boolean visible;
 		attribute SizePolicy hSizePolicy;
@@ -82,7 +82,7 @@ module Arts {
 	};
 
 	interface Frame : Widget {
-		void constructor( Widget tqparent );
+		void constructor( Widget parent );
 
 		attribute long margin;
 		attribute long linewidth;
@@ -118,7 +118,7 @@ module Arts {
 
 		Usage is quite simple: Add the widgets you have in the right order
 		to the layoutbox by calling addWidget().
-		Thats it, no ._addChild or .tqparent with this widget.
+		Thats it, no ._addChild or .parent with this widget.
 
 		For more information see QBoxLayout.
 		(akrille)
@@ -173,7 +173,7 @@ module Arts {
 		Usage is quite simple: Create the Widget you want to be hidable inside
 		a container like LayoutBox or a normal widget. Then create the PopupBox
 		and call <Name_of_PopupBox>.widget( <Name_of_your_Container> ).
-		Thats it, no ._addChild or .tqparent with this widget.
+		Thats it, no ._addChild or .parent with this widget.
 		(akrille)
 		*/
 	interface PopupBox : Frame {
@@ -186,8 +186,8 @@ module Arts {
 	};
 
 	interface Button : Widget {
-		void constructor( Widget tqparent );
-		void constructor( string text, Widget tqparent );
+		void constructor( Widget parent );
+		void constructor( string text, Widget parent );
 
 		attribute string text;
 		attribute boolean toggle;
@@ -205,7 +205,7 @@ module Arts {
 	};
 
 	interface Fader : Widget {
-		void constructor( Widget tqparent );
+		void constructor( Widget parent );
 
 		attribute string caption, color;
 		attribute float min, max, value;
@@ -213,21 +213,21 @@ module Arts {
 	};
 
 	interface LineEdit : Widget {
-		void constructor( Widget tqparent );
+		void constructor( Widget parent );
 
 		attribute string caption;
 		attribute string text;
 	};
 
 	interface SpinBox : Widget {
-		void constructor( Widget tqparent );
+		void constructor( Widget parent );
 
 		attribute string caption;
 		attribute long min, max, value;
 	};
 
 	interface ComboBox : Widget {
-		void constructor( Widget tqparent );
+		void constructor( Widget parent );
 
 		attribute string caption;
 		attribute sequence<string> choices;
@@ -235,7 +235,7 @@ module Arts {
 	};
 
 	interface Graph : Widget {
-		void constructor( Widget tqparent );
+		void constructor( Widget parent );
 
 		attribute string caption;
 		attribute float minx, maxx, miny, maxy;
diff --git a/arts/gui/kde/artstestgui.cpp b/arts/gui/kde/artstestgui.cpp
index 9464ac7a..c7532003 100644
--- a/arts/gui/kde/artstestgui.cpp
+++ b/arts/gui/kde/artstestgui.cpp
@@ -41,7 +41,7 @@ int main(int argc, char **argv)
 	w.width(500); w.height(350); w.show();
 
 	Button b;
-	b.tqparent(w);
+	b.parent(w);
 	b.x(10);
 	b.y(10);
 	b.width(100);
@@ -50,7 +50,7 @@ int main(int argc, char **argv)
 	b.show();
 
 	Button b2;
-	b2.tqparent(w);
+	b2.parent(w);
 	b2.x(10);
 	b2.y(30);
 	b2.width(100);
@@ -59,7 +59,7 @@ int main(int argc, char **argv)
 	b2.show();
 
 	Poti p;
-	p.tqparent(w);
+	p.parent(w);
 	p.x(150);
 	p.y(10);
 	p.caption("delay (ms)");
@@ -70,7 +70,7 @@ int main(int argc, char **argv)
 	p.show();
 
 	Poti q;
-	q.tqparent(w);
+	q.parent(w);
 	q.x(250);
 	q.y(10);
 	q.caption("delay (ms)");
@@ -81,7 +81,7 @@ int main(int argc, char **argv)
 	q.show();
 
 	Graph g;
-	g.tqparent(w);
+	g.parent(w);
 	g.x(50);
 	g.y(70);
 	g.width(400);
diff --git a/arts/gui/kde/kartswidget.cpp b/arts/gui/kde/kartswidget.cpp
index 5188e81a..763239f7 100644
--- a/arts/gui/kde/kartswidget.cpp
+++ b/arts/gui/kde/kartswidget.cpp
@@ -31,31 +31,31 @@ public:
 	TQHBoxLayout *tqlayout;
 };
 
-KArtsWidget::KArtsWidget( TQWidget* tqparent, const char* name )
-	:TQWidget( tqparent, name ), _content( Arts::Widget::null() )
+KArtsWidget::KArtsWidget( TQWidget* parent, const char* name )
+	:TQWidget( parent, name ), _content( Arts::Widget::null() )
 {
 	d = new KArtsWidgetPrivate;
 	d->tqlayout = new TQHBoxLayout(this);
 }
 
-KArtsWidget::KArtsWidget( Arts::Widget content, TQWidget* tqparent, const char* name )
-	:TQWidget( tqparent, name ), _content( Arts::Widget::null())
+KArtsWidget::KArtsWidget( Arts::Widget content, TQWidget* parent, const char* name )
+	:TQWidget( parent, name ), _content( Arts::Widget::null())
 {
 	d = new KArtsWidgetPrivate;
 	d->tqlayout = new TQHBoxLayout(this);
 	setContent(content);
 }
 
-KArtsWidget::KArtsWidget( Arts::Widget content, TQWidget* tqparent, const char* name, WFlags wflags )
-	:TQWidget( tqparent, name, wflags ), _content( Arts::Widget::null() )
+KArtsWidget::KArtsWidget( Arts::Widget content, TQWidget* parent, const char* name, WFlags wflags )
+	:TQWidget( parent, name, wflags ), _content( Arts::Widget::null() )
 {
 	d = new KArtsWidgetPrivate;
 	d->tqlayout = new TQHBoxLayout( this );
 	setContent( content );
 }
 
-KArtsWidget::KArtsWidget(TQWidget* tqparent, const char* name, WFlags wflags )
-	:TQWidget(tqparent, name, wflags ), _content(Arts::Widget::null())
+KArtsWidget::KArtsWidget(TQWidget* parent, const char* name, WFlags wflags )
+	:TQWidget(parent, name, wflags ), _content(Arts::Widget::null())
 {
 	d = new KArtsWidgetPrivate;
 	d->tqlayout = new TQHBoxLayout(this);
diff --git a/arts/gui/kde/kbutton_impl.cpp b/arts/gui/kde/kbutton_impl.cpp
index 95f7699f..34c5791b 100644
--- a/arts/gui/kde/kbutton_impl.cpp
+++ b/arts/gui/kde/kbutton_impl.cpp
@@ -72,12 +72,12 @@ KButton_impl::KButton_impl( TQPushButton * widget )
 
 void KButton_impl::constructor( Widget p )
 {
-	tqparent( p );
+	parent( p );
 }
 
 void KButton_impl::constructor( const string & t, Widget p )
 {
-	tqparent( p );
+	parent( p );
 	text( t );
 }
 
diff --git a/arts/gui/kde/kbutton_impl.h b/arts/gui/kde/kbutton_impl.h
index 4db27c84..be3aa2f6 100644
--- a/arts/gui/kde/kbutton_impl.h
+++ b/arts/gui/kde/kbutton_impl.h
@@ -55,7 +55,7 @@ protected:
 
 public:
 	KButton_impl( TQPushButton * w = 0 );
-	void constructor( Widget tqparent );
+	void constructor( Widget parent );
 	void constructor( const std::string &, Widget );
 
 	void emitClicked();
diff --git a/arts/gui/kde/kcombobox_impl.h b/arts/gui/kde/kcombobox_impl.h
index ad8e5739..f9de6c55 100644
--- a/arts/gui/kde/kcombobox_impl.h
+++ b/arts/gui/kde/kcombobox_impl.h
@@ -57,7 +57,7 @@ protected:
 
 public:
 	KComboBox_impl( KComboBox * w = 0 );
-	void constructor( Widget p ) { tqparent( p ); }
+	void constructor( Widget p ) { parent( p ); }
 
 	std::string caption();
 	void caption(const std::string & newCaption);
diff --git a/arts/gui/kde/kfader.cpp b/arts/gui/kde/kfader.cpp
index 239d303a..e5179f9f 100644
--- a/arts/gui/kde/kfader.cpp
+++ b/arts/gui/kde/kfader.cpp
@@ -5,14 +5,14 @@ void KFader::init()
 {
 }
 
-KFader::KFader( TQWidget * tqparent, const char * name )
-	: TQSlider( Qt::Vertical, tqparent, name )
+KFader::KFader( TQWidget * parent, const char * name )
+	: TQSlider( Qt::Vertical, parent, name )
 {
 	init();
 }
 
-KFader::KFader( int minValue, int maxValue, int pageStep, int value, TQWidget * tqparent, const char * name )
-	: TQSlider( minValue, maxValue, pageStep, value, Qt::Vertical, tqparent, name )
+KFader::KFader( int minValue, int maxValue, int pageStep, int value, TQWidget * parent, const char * name )
+	: TQSlider( minValue, maxValue, pageStep, value, Qt::Vertical, parent, name )
 {
 	init();
 }
diff --git a/arts/gui/kde/kfader.h b/arts/gui/kde/kfader.h
index 33df0d40..6b63e066 100644
--- a/arts/gui/kde/kfader.h
+++ b/arts/gui/kde/kfader.h
@@ -32,8 +32,8 @@ class KFader : public TQSlider
 	protected:
 		void init();
 	public:
-		KFader( TQWidget * tqparent = 0, const char * name = 0 );
-		KFader( int minValue, int maxValue, int pageStep, int value, TQWidget * tqparent = 0, const char * name = 0 );
+		KFader( TQWidget * parent = 0, const char * name = 0 );
+		KFader( int minValue, int maxValue, int pageStep, int value, TQWidget * parent = 0, const char * name = 0 );
 
 		virtual ~KFader();
 
diff --git a/arts/gui/kde/kfader_impl.h b/arts/gui/kde/kfader_impl.h
index e15695f0..9ef877bd 100644
--- a/arts/gui/kde/kfader_impl.h
+++ b/arts/gui/kde/kfader_impl.h
@@ -63,7 +63,7 @@ protected:
 
 public:
 	KFader_impl( KFader * w = 0 );
-	void constructor( Widget p ) { tqparent( p ); }
+	void constructor( Widget p ) { parent( p ); }
 
 	std::string caption();
 	void caption(const std::string& newText);
diff --git a/arts/gui/kde/kframe_impl.h b/arts/gui/kde/kframe_impl.h
index ae2e79a4..57af42e6 100644
--- a/arts/gui/kde/kframe_impl.h
+++ b/arts/gui/kde/kframe_impl.h
@@ -34,7 +34,7 @@ class KDE_EXPORT KFrame_impl : virtual public Arts::Frame_skel,
 
 	public:
 		KFrame_impl( TQFrame * widget = 0 );
-		inline void constructor( Widget p ) { tqparent( p ); }
+		inline void constructor( Widget p ) { parent( p ); }
 
 		long margin();
 		void margin( long m );
diff --git a/arts/gui/kde/kgraph.cpp b/arts/gui/kde/kgraph.cpp
index 96d18c5c..1278ba21 100644
--- a/arts/gui/kde/kgraph.cpp
+++ b/arts/gui/kde/kgraph.cpp
@@ -31,8 +31,8 @@
 using namespace Arts;
 using namespace std;
 
-KGraph::KGraph( TQWidget * tqparent, const char * name )
-	: TQWidget( tqparent, name )
+KGraph::KGraph( TQWidget * parent, const char * name )
+	: TQWidget( parent, name )
 {
 	setBackgroundColor(white);
 
diff --git a/arts/gui/kde/kgraph.h b/arts/gui/kde/kgraph.h
index e9f772ff..a1904aa1 100644
--- a/arts/gui/kde/kgraph.h
+++ b/arts/gui/kde/kgraph.h
@@ -47,7 +47,7 @@ protected:
 	inline GraphPoint q2gPoint(const TQPoint &qp);
 	inline TQPoint g2qPoint(const GraphPoint &gp);
 public:
-	KGraph( TQWidget * tqparent = 0, const char * name = 0 );
+	KGraph( TQWidget * parent = 0, const char * name = 0 );
 	virtual ~KGraph();
 
 	void addLine(Arts::KGraphLine_impl *line);
diff --git a/arts/gui/kde/kgraph_impl.h b/arts/gui/kde/kgraph_impl.h
index 2a603208..408ad961 100644
--- a/arts/gui/kde/kgraph_impl.h
+++ b/arts/gui/kde/kgraph_impl.h
@@ -44,7 +44,7 @@ protected:
 
 public:
 	KGraph_impl( KGraph * w = 0 );
-	void constructor( Widget p ) { tqparent( p ); }
+	void constructor( Widget p ) { parent( p ); }
 
 	std::string caption();
 	void caption(const std::string& newCaption);
diff --git a/arts/gui/kde/klabel_impl.h b/arts/gui/kde/klabel_impl.h
index 8b78bedc..205d041d 100644
--- a/arts/gui/kde/klabel_impl.h
+++ b/arts/gui/kde/klabel_impl.h
@@ -42,7 +42,7 @@ protected:
 	RotateLabel* _label;
 public:
 	KLabel_impl( TQFrame* w=0 );
-	void constructor( Widget p ) { tqparent( p ); }
+	void constructor( Widget p ) { parent( p ); }
 
 	std::string text();
 	void text( const std::string& newtext );
diff --git a/arts/gui/kde/klayoutbox_impl.cpp b/arts/gui/kde/klayoutbox_impl.cpp
index 6cbe9873..9aeee822 100644
--- a/arts/gui/kde/klayoutbox_impl.cpp
+++ b/arts/gui/kde/klayoutbox_impl.cpp
@@ -40,14 +40,14 @@ KLayoutBox_impl::~KLayoutBox_impl() {
 }
 
 void KLayoutBox_impl::addWidget( Arts::Widget widget, long stretch, long align ) {
-	widget.tqparent( self() );
+	widget.parent( self() );
 	this->_addChild( widget, "layoutbox_item" );
 	TQWidget * tmp = KWidgetRepo::the()->lookupTQWidget( widget.widgetID() );
 	_layout->addWidget( tmp, stretch, align );
 }
 
 void KLayoutBox_impl::insertWidget( long index, Arts::Widget widget, long stretch, long align ) {
-	widget.tqparent( self() );
+	widget.parent( self() );
 	this->_addChild( widget, "layoutbox_item" );
 	TQWidget * tmp = KWidgetRepo::the()->lookupTQWidget( widget.widgetID() );
 	_layout->insertWidget( index, tmp, stretch, align );
diff --git a/arts/gui/kde/klevelmeter_firebars.cpp b/arts/gui/kde/klevelmeter_firebars.cpp
index ffb99c3e..5589b772 100644
--- a/arts/gui/kde/klevelmeter_firebars.cpp
+++ b/arts/gui/kde/klevelmeter_firebars.cpp
@@ -59,8 +59,8 @@ kdDebug() << k_funcinfo << dir << endl;
 	p.end();
 }
 
-KLevelMeter_FireBars::KLevelMeter_FireBars( Arts::KLevelMeter_impl* impl, TQWidget* tqparent, long substyle, long count, Arts::Direction dir, float _dbmin, float _dbmax ) : KLevelMeter_Template( impl, tqparent, substyle, count, dir, _dbmin, _dbmax ) {
-//kdDebug()<<"KLevelMeter_FireBars::KLevelMeter_FireBars( Arts::KLevelMeter_impl* "<<impl<<", TQWidget* "<<tqparent<<", long "<<substyle<<", long "<<count<<", float "<<_dbmin<<", float "<<_dbmax<<" )"<<endl;
+KLevelMeter_FireBars::KLevelMeter_FireBars( Arts::KLevelMeter_impl* impl, TQWidget* parent, long substyle, long count, Arts::Direction dir, float _dbmin, float _dbmax ) : KLevelMeter_Template( impl, parent, substyle, count, dir, _dbmin, _dbmax ) {
+//kdDebug()<<"KLevelMeter_FireBars::KLevelMeter_FireBars( Arts::KLevelMeter_impl* "<<impl<<", TQWidget* "<<parent<<", long "<<substyle<<", long "<<count<<", float "<<_dbmin<<", float "<<_dbmax<<" )"<<endl;
 	this->setMinimumSize( 5, 5 );
 	_bar = new KLevelMeter_FireBars_private( this, 0 );
 	_peakwidget = new TQWidget( this );
diff --git a/arts/gui/kde/klevelmeter_impl.cpp b/arts/gui/kde/klevelmeter_impl.cpp
index b6845dc4..418108ad 100644
--- a/arts/gui/kde/klevelmeter_impl.cpp
+++ b/arts/gui/kde/klevelmeter_impl.cpp
@@ -41,8 +41,8 @@
 using namespace Arts;
 using namespace std;
 
-KLevelMeter_Private::KLevelMeter_Private( KLevelMeter_impl* impl, TQFrame* frame, LevelMeterStyle defstyle, TQObject* tqparent, const char* name )
-   : TQObject( tqparent, name )
+KLevelMeter_Private::KLevelMeter_Private( KLevelMeter_impl* impl, TQFrame* frame, LevelMeterStyle defstyle, TQObject* parent, const char* name )
+   : TQObject( parent, name )
    , _impl( impl )
    , _frame( frame )
    , _levelmeter( 0 )
diff --git a/arts/gui/kde/klevelmeter_linebars.cpp b/arts/gui/kde/klevelmeter_linebars.cpp
index 5d8b4b3c..37dfe4d3 100644
--- a/arts/gui/kde/klevelmeter_linebars.cpp
+++ b/arts/gui/kde/klevelmeter_linebars.cpp
@@ -24,11 +24,11 @@
 #include <tqpainter.h>
 #include <tqpixmap.h>
 
-KLevelMeter_LineBars::KLevelMeter_LineBars( Arts::KLevelMeter_impl* impl, TQWidget* tqparent, long substyle, long count, Arts::Direction dir, float _dbmin, float _dbmax ) : KLevelMeter_Template( impl, tqparent, substyle, count, dir, _dbmin, _dbmax ) 
+KLevelMeter_LineBars::KLevelMeter_LineBars( Arts::KLevelMeter_impl* impl, TQWidget* parent, long substyle, long count, Arts::Direction dir, float _dbmin, float _dbmax ) : KLevelMeter_Template( impl, parent, substyle, count, dir, _dbmin, _dbmax ) 
  , _value( 0.0 )
  , _peak( 0.0 )
 {
-//kdDebug()<<"KLevelMeter_LineBars::KLevelMeter_LineBars( Arts::KLevelMeter_impl* "<<impl<<", TQWidget* "<<tqparent<<", long "<<substyle<<", long "<<count<<", Arts::Direction "<<dir<<", float "<<_dbmin<<", float "<<_dbmax<<" )"<<endl;
+//kdDebug()<<"KLevelMeter_LineBars::KLevelMeter_LineBars( Arts::KLevelMeter_impl* "<<impl<<", TQWidget* "<<parent<<", long "<<substyle<<", long "<<count<<", Arts::Direction "<<dir<<", float "<<_dbmin<<", float "<<_dbmax<<" )"<<endl;
 	this->setMinimumSize( 5, 5 );
 	this->substyle( substyle );
 	_stdcolors = tqcolorGroup();
diff --git a/arts/gui/kde/klevelmeter_normalbars.cpp b/arts/gui/kde/klevelmeter_normalbars.cpp
index 9263737a..29593551 100644
--- a/arts/gui/kde/klevelmeter_normalbars.cpp
+++ b/arts/gui/kde/klevelmeter_normalbars.cpp
@@ -24,8 +24,8 @@
 #include <tqpainter.h>
 #include <tqlayout.h>
 
-KLevelMeter_NormalBars::KLevelMeter_NormalBars( Arts::KLevelMeter_impl* impl, TQWidget* tqparent, long substyle, long count, Arts::Direction dir, float _dbmin, float _dbmax ) : KLevelMeter_Template( impl, tqparent, substyle, count, dir, _dbmin, _dbmax ) {
-//kdDebug()<<"KLevelMeter_NormalBars::KLevelMeter_NormalBars( Arts::KLevelMeter_impl* "<<impl<<", TQWidget* "<<tqparent<<", long "<<substyle<<", long "<<count<<", float "<<_dbmin<<", float "<<_dbmax<<" )"<<endl;
+KLevelMeter_NormalBars::KLevelMeter_NormalBars( Arts::KLevelMeter_impl* impl, TQWidget* parent, long substyle, long count, Arts::Direction dir, float _dbmin, float _dbmax ) : KLevelMeter_Template( impl, parent, substyle, count, dir, _dbmin, _dbmax ) {
+//kdDebug()<<"KLevelMeter_NormalBars::KLevelMeter_NormalBars( Arts::KLevelMeter_impl* "<<impl<<", TQWidget* "<<parent<<", long "<<substyle<<", long "<<count<<", float "<<_dbmin<<", float "<<_dbmax<<" )"<<endl;
 	_layout = new TQBoxLayout( this, TQBoxLayout::BottomToTop );
 }
 
diff --git a/arts/gui/kde/klevelmeter_normalbars.h b/arts/gui/kde/klevelmeter_normalbars.h
index b141f2fc..8fc02208 100644
--- a/arts/gui/kde/klevelmeter_normalbars.h
+++ b/arts/gui/kde/klevelmeter_normalbars.h
@@ -55,7 +55,7 @@ private:
 	TQColor _color;
 	bool _on;
 public:
-	Bar( float min, float max, TQColor color, TQWidget* tqparent ) : TQWidget( tqparent ), _min( min ), _max( max ), _color( color ), _on( false ) {
+	Bar( float min, float max, TQColor color, TQWidget* parent ) : TQWidget( parent ), _min( min ), _max( max ), _color( color ), _on( false ) {
 		setBackgroundColor( _color.dark() );
 	}
 	void setValue( float n ) {
diff --git a/arts/gui/kde/klevelmeter_small.cpp b/arts/gui/kde/klevelmeter_small.cpp
index 3c07bc6b..c74dfa44 100644
--- a/arts/gui/kde/klevelmeter_small.cpp
+++ b/arts/gui/kde/klevelmeter_small.cpp
@@ -23,8 +23,8 @@
 #include <kdebug.h>
 #include <tqpainter.h>
 
-KLevelMeter_Small::KLevelMeter_Small( Arts::KLevelMeter_impl* impl, TQWidget* tqparent, long substyle, long count, Arts::Direction dir, float _dbmin, float _dbmax ) : KLevelMeter_Template( impl, tqparent, substyle, count, dir, _dbmin, _dbmax ) {
-//kdDebug()<<"KLevelMeter_Small::KLevelMeter_Small( Arts::KLevelMeter_impl* "<<impl<<", TQWidget* "<<tqparent<<", long "<<substyle<<", long "<<count<<", float "<<_dbmin<<", float "<<_dbmax<<" )"<<endl;
+KLevelMeter_Small::KLevelMeter_Small( Arts::KLevelMeter_impl* impl, TQWidget* parent, long substyle, long count, Arts::Direction dir, float _dbmin, float _dbmax ) : KLevelMeter_Template( impl, parent, substyle, count, dir, _dbmin, _dbmax ) {
+//kdDebug()<<"KLevelMeter_Small::KLevelMeter_Small( Arts::KLevelMeter_impl* "<<impl<<", TQWidget* "<<parent<<", long "<<substyle<<", long "<<count<<", float "<<_dbmin<<", float "<<_dbmax<<" )"<<endl;
 }
 
 void KLevelMeter_Small::invalue( float n, float p ) {
diff --git a/arts/gui/kde/klineedit_impl.h b/arts/gui/kde/klineedit_impl.h
index 12ab7532..6164a078 100644
--- a/arts/gui/kde/klineedit_impl.h
+++ b/arts/gui/kde/klineedit_impl.h
@@ -38,7 +38,7 @@ protected:
 
 public:
 	KLineEdit_impl( KLineEdit * w = 0 );
-	void constructor( Widget p ) { tqparent( p ); }
+	void constructor( Widget p ) { parent( p ); }
 
 	std::string caption();
 	void caption(const std::string& newCaption);
diff --git a/arts/gui/kde/kpopupbox_impl.cpp b/arts/gui/kde/kpopupbox_impl.cpp
index 5438d131..e685b1ae 100644
--- a/arts/gui/kde/kpopupbox_impl.cpp
+++ b/arts/gui/kde/kpopupbox_impl.cpp
@@ -43,7 +43,7 @@ Direction KPopupBox_impl::direction() { return _widget->direction(); }
 void KPopupBox_impl::direction( Direction n ) { _widget->direction( n ); }
 
 void KPopupBox_impl::widget( Arts::Widget widget ) {
-	widget.tqparent( self() );
+	widget.parent( self() );
 	this->_addChild( widget, "PopupBox_child" );
 	_widget->setWidget( widget );
 }
@@ -54,7 +54,7 @@ void KPopupBox_impl::name( const std::string& n ) { _name = ""; _name = n; _widg
 
 // Following the private class:
 
-KPopupBox_widget::KPopupBox_widget( TQWidget *tqparent, const char* name ) : TQFrame( tqparent,name )
+KPopupBox_widget::KPopupBox_widget( TQWidget *parent, const char* name ) : TQFrame( parent,name )
 {
 	this->setFrameShape( TQFrame::Box );
 	this->setMargin( 1 ); this->setLineWidth( 1 );
diff --git a/arts/gui/kde/kpopupbox_private.h b/arts/gui/kde/kpopupbox_private.h
index 06a58ebc..b9b38e7f 100644
--- a/arts/gui/kde/kpopupbox_private.h
+++ b/arts/gui/kde/kpopupbox_private.h
@@ -83,7 +83,7 @@ class HandleDrag : public TQWidget {
    Q_OBJECT
   TQ_OBJECT
 public:
-	HandleDrag( TQWidget *tqparent, const char* name=0 ) : TQWidget( tqparent,name ) {}
+	HandleDrag( TQWidget *parent, const char* name=0 ) : TQWidget( parent,name ) {}
 	void paintEvent( TQPaintEvent * ) {
 		TQPainter p( this );
 		TQStyle::SFlags flags = TQStyle::Style_Default;
@@ -116,7 +116,7 @@ private:
 	TQBoxLayout::Direction _dir;
 	TQPixmap _pmleft, _pmright, _pmup, _pmdown;
 public:
-	ShowButton( TQWidget *tqparent, const char* name=0 ) : TQPushButton( tqparent,name ), _dir( TQBoxLayout::LeftToRight )
+	ShowButton( TQWidget *parent, const char* name=0 ) : TQPushButton( parent,name ), _dir( TQBoxLayout::LeftToRight )
 	{
 		connect( this, TQT_SIGNAL( toggled( bool ) ), this, TQT_SLOT( owntoggle( bool ) ) );
 		setToggleButton( true );
@@ -172,7 +172,7 @@ class OwnButton : public TQPushButton {
 private:
 	TQPixmap _pmown, _pminside;
 public:
-	OwnButton( TQWidget *tqparent, const char* name=0 ) : TQPushButton( tqparent,name )
+	OwnButton( TQWidget *parent, const char* name=0 ) : TQPushButton( parent,name )
 	{
 		connect( this, TQT_SIGNAL( toggled( bool ) ), this, TQT_SLOT( toggle( bool ) ) );
 		setToggleButton( true );
diff --git a/arts/gui/kde/kpoti.cpp b/arts/gui/kde/kpoti.cpp
index d7cf50df..03a99c29 100644
--- a/arts/gui/kde/kpoti.cpp
+++ b/arts/gui/kde/kpoti.cpp
@@ -62,14 +62,14 @@ struct KPoti::KPotiPrivate
 			dbp.setPen( TQt::NoPen );
 			TQRect drawRect = bgdb.rect();
 
-			// create tqmask
-			TQBitmap tqmask( bgdb.size(), true );
-			TQPainter maskpainter( &tqmask );
+			// create mask
+			TQBitmap mask( bgdb.size(), true );
+			TQPainter maskpainter( &mask );
 			maskpainter.setPen( TQt::NoPen );
 			maskpainter.setBrush( TQt::color1 );
 			maskpainter.drawEllipse( drawRect );
 			maskpainter.end();
-			bgdb.setMask( tqmask );
+			bgdb.setMask( mask );
 
 			// inset shadow
 			KPixmap gradient( bgdb.size() );
@@ -102,14 +102,14 @@ struct KPoti::KPotiPrivate
 			dbp.setPen( TQt::NoPen );
 			TQRect drawRect( potidb.rect() );
 
-			// create tqmask
-			TQBitmap tqmask( potidb.size(), true );
-			TQPainter maskpainter( &tqmask );
+			// create mask
+			TQBitmap mask( potidb.size(), true );
+			TQPainter maskpainter( &mask );
 			maskpainter.setPen( TQt::NoPen );
 			maskpainter.setBrush( TQt::color1 );
 			maskpainter.drawEllipse( drawRect );
 			maskpainter.end();
-			potidb.setMask( tqmask );
+			potidb.setMask( mask );
 
 			KPixmap gradient( potidb.size() );
 			KPixmapEffect::gradient( gradient, potiColor.dark( 130 ), potiColor.light( 130 ), KPixmapEffect::DiagonalGradient );
@@ -169,10 +169,10 @@ void KPoti::setText( const TQString & text )
 /**
   Constructs a poti.
 
-  The \e tqparent and \e name arguments are sent to the TQWidget constructor.
+  The \e parent and \e name arguments are sent to the TQWidget constructor.
 */
-KPoti::KPoti( TQWidget *tqparent, const char *name )
-    : TQFrame( tqparent, name, WResizeNoErase | WRepaintNoErase )
+KPoti::KPoti( TQWidget *parent, const char *name )
+    : TQFrame( parent, name, WResizeNoErase | WRepaintNoErase )
 	, d( 0 )
 {
     init();
@@ -188,12 +188,12 @@ KPoti::KPoti( TQWidget *tqparent, const char *name )
   \arg \e step is the page step value.
   \arg \e value is the initial value.
 
-  The \e tqparent and \e name arguments are sent to the TQWidget constructor.
+  The \e parent and \e name arguments are sent to the TQWidget constructor.
 */
 
 KPoti::KPoti( int minValue, int maxValue, int step,
-		  int value, TQWidget *tqparent, const char *name )
-    : TQFrame( tqparent, name, WResizeNoErase | WRepaintNoErase )
+		  int value, TQWidget *parent, const char *name )
+    : TQFrame( parent, name, WResizeNoErase | WRepaintNoErase )
 	, TQRangeControl( minValue, maxValue, 1, step, value )
 	, d( 0 )
 {
diff --git a/arts/gui/kde/kpoti.h b/arts/gui/kde/kpoti.h
index 80e32add..d9013c8a 100644
--- a/arts/gui/kde/kpoti.h
+++ b/arts/gui/kde/kpoti.h
@@ -34,9 +34,9 @@ class KPoti : public TQFrame, public TQRangeControl
   TQ_OBJECT
 public:
 
-    KPoti( TQWidget *tqparent=0, const char *name=0 );
+    KPoti( TQWidget *parent=0, const char *name=0 );
     KPoti( int minValue, int maxValue, int step, int value,
-	     TQWidget *tqparent=0, const char *name=0 );
+	     TQWidget *parent=0, const char *name=0 );
 
     ~KPoti();
 
diff --git a/arts/gui/kde/kspinbox_impl.h b/arts/gui/kde/kspinbox_impl.h
index 714da93f..0a926f83 100644
--- a/arts/gui/kde/kspinbox_impl.h
+++ b/arts/gui/kde/kspinbox_impl.h
@@ -55,7 +55,7 @@ protected:
 
 public:
 	KSpinBox_impl( TQSpinBox * w = 0 );
-	void constructor( Widget p ) { tqparent( p ); }
+	void constructor( Widget p ) { parent( p ); }
 
 	std::string caption();
 	void caption(const std::string& newCaption);
diff --git a/arts/gui/kde/kwidget_impl.cpp b/arts/gui/kde/kwidget_impl.cpp
index b899f0cd..b716f4c3 100644
--- a/arts/gui/kde/kwidget_impl.cpp
+++ b/arts/gui/kde/kwidget_impl.cpp
@@ -65,24 +65,24 @@ long KWidget_impl::widgetID()
 	return _widgetID;
 }
 
-Widget KWidget_impl::tqparent()
+Widget KWidget_impl::parent()
 {
 	return KWidgetRepo::the()->lookupWidget(_parentID);
 }
 
-void KWidget_impl::tqparent(Arts::Widget newParent)
+void KWidget_impl::parent(Arts::Widget newParent)
 {
 	if(!newParent.isNull())
 	{
 		_parentID = newParent.widgetID();
 
-		TQWidget *qtqparent;
-		qtqparent = KWidgetRepo::the()->lookupTQWidget(newParent.widgetID());
-		if( qtqparent != 0 )
+		TQWidget *qparent;
+		qparent = KWidgetRepo::the()->lookupTQWidget(newParent.widgetID());
+		if( qparent != 0 )
 		{
 			TQPoint pos(x(),y());
 			bool showIt = visible();
-			_qwidget->reparent(qtqparent, pos, showIt);
+			_qwidget->reparent(qparent, pos, showIt);
 		}
 	}
 	else
diff --git a/arts/gui/kde/kwidget_impl.h b/arts/gui/kde/kwidget_impl.h
index 40d7216c..6a0c45c0 100644
--- a/arts/gui/kde/kwidget_impl.h
+++ b/arts/gui/kde/kwidget_impl.h
@@ -43,8 +43,8 @@ public:
 	~KWidget_impl();
 
 	long widgetID();
-	Widget tqparent();
-	void tqparent(Arts::Widget);
+	Widget parent();
+	void parent(Arts::Widget);
 	long x();
 	void x(long newX);
 	long y();
diff --git a/arts/modules/README.environments b/arts/modules/README.environments
index 5dc6c66e..0ac64df5 100644
--- a/arts/modules/README.environments
+++ b/arts/modules/README.environments
@@ -155,7 +155,7 @@ to tell the Item in which environment it lives. It also uses setContainer(
 Container::null()) once the Item gets removed. Which container the Item
 is in can be seen in the
 
-    readonly attribute Container tqparent;
+    readonly attribute Container parent;
 
 Upon serialization, the container uses
 
diff --git a/arts/modules/common/artsmodulescommon.idl b/arts/modules/common/artsmodulescommon.idl
index 7f657568..10ccd218 100644
--- a/arts/modules/common/artsmodulescommon.idl
+++ b/arts/modules/common/artsmodulescommon.idl
@@ -72,7 +72,7 @@ module Environment {
 		/**
 		 * the container the item lives in
 		 */
-		readonly attribute Container tqparent;
+		readonly attribute Container parent;
 
 		/**
 		 * called by the container to insert/remove item from/to the
@@ -150,7 +150,7 @@ interface EffectRackItemGui {
 };
 
 interface EffectRackSlot {
-	void constructor( Widget tqparent, Widget effect, EffectRackItemGui effectrackgui );
+	void constructor( Widget parent, Widget effect, EffectRackItemGui effectrackgui );
 	/*writeonly*/ attribute boolean removeslot;
 	/*writeonly*/ attribute boolean tomaster;
 };
diff --git a/arts/modules/common/effectrackslot_impl.cc b/arts/modules/common/effectrackslot_impl.cc
index 359c40a3..8e7e48e8 100644
--- a/arts/modules/common/effectrackslot_impl.cc
+++ b/arts/modules/common/effectrackslot_impl.cc
@@ -42,23 +42,23 @@ class EffectRackSlot_impl : virtual public EffectRackSlot_skel
 		{
 		}
 
-		void constructor( Widget tqparent, Widget effect, EffectRackItemGui effectrackgui )
+		void constructor( Widget parent, Widget effect, EffectRackItemGui effectrackgui )
 		{
 			_effectrackgui = effectrackgui;
 
-			_hbox.tqparent( tqparent );
+			_hbox.parent( parent );
 			_hbox.margin( 0 );
 			_hbox.spacing( 0 );
 			_hbox.framestyle( Sunken | Panel );
 			_hbox.linewidth( 1 );
 			_hbox.show();
 
-			_buttonbox.tqparent( _hbox );
+			_buttonbox.parent( _hbox );
 			_buttonbox.margin( 0 );
 			_buttonbox.spacing( 0 );
 			_buttonbox.show();
 
-			_removeButton.tqparent( _buttonbox );
+			_removeButton.parent( _buttonbox );
 			_removeButton.text( "x" );
 			_removeButton.hSizePolicy( spFixed );
 			_removeButton.width( 20 );
@@ -66,7 +66,7 @@ class EffectRackSlot_impl : virtual public EffectRackSlot_skel
 			connect( _removeButton, "clicked_changed", self(), "removeslot" );
 			_removeButton.show();
 
-			_masterButton.tqparent( _buttonbox );
+			_masterButton.parent( _buttonbox );
 			_masterButton.text( "MM" );
 			_masterButton.toggle( true );
 			_masterButton.hSizePolicy( spFixed );
@@ -75,7 +75,7 @@ class EffectRackSlot_impl : virtual public EffectRackSlot_skel
 			connect( _masterButton, "pressed_changed", self(), "tomaster" );
 			_masterButton.show();
 
-			_frame.tqparent( _hbox );
+			_frame.parent( _hbox );
 			_frame.margin( 5 );
 			_frame.spacing( 0 );
 			_frame.framestyle( Raised | Panel );
@@ -85,10 +85,10 @@ class EffectRackSlot_impl : virtual public EffectRackSlot_skel
 			_frame.show();
 
 			_effect = effect;
-			_effect.tqparent( _frame );
+			_effect.parent( _frame );
 			_effect.show();
 
-			_spacer.tqparent( _frame );
+			_spacer.parent( _frame );
 			_spacer.hSizePolicy( spExpanding );
 			_spacer.show();
 		}
diff --git a/arts/modules/common/env_effectrackitem_impl.cc b/arts/modules/common/env_effectrackitem_impl.cc
index ac76db70..50fb116e 100644
--- a/arts/modules/common/env_effectrackitem_impl.cc
+++ b/arts/modules/common/env_effectrackitem_impl.cc
@@ -226,7 +226,7 @@ public:
 			name = LineEdit();
 			name.caption("name");
 			name.text(_effectRack.name());
-			name.tqparent(hbox);
+			name.parent(hbox);
 			connect(name,"text_changed", _effectRack, "name");
 #endif
 
@@ -248,7 +248,7 @@ public:
 			typebox = ComboBox();
 			typebox.choices(choices);
 			typebox.value(_type);
-			typebox.tqparent(hbox);
+			typebox.parent(hbox);
 			connect(typebox,"value_changed", self(), "type");
 
 			addbutton = Button( "add", hbox );
@@ -260,7 +260,7 @@ public:
 			effect_vbox.show();
 
 			Frame spacer;
-			spacer.tqparent( effect_vbox );
+			spacer.parent( effect_vbox );
 			spacer.vSizePolicy( spExpanding );
 			spacer.show();
 			effect_vbox._addChild( spacer, "spacer" );
diff --git a/arts/modules/common/env_instrumentitem_impl.cc b/arts/modules/common/env_instrumentitem_impl.cc
index 0b979b6c..17959ca0 100644
--- a/arts/modules/common/env_instrumentitem_impl.cc
+++ b/arts/modules/common/env_instrumentitem_impl.cc
@@ -98,7 +98,7 @@ public:
 		LineEdit edit;
 		edit.x(20); edit.y(10); edit.width(120); edit.height(40);
 		edit.text(instrument.filename());
-		edit.tqparent(panel);
+		edit.parent(panel);
 		edit.show();
 		connect(edit,"text_changed", instrument, "filename");
 		panel._addChild(edit,"editWidget");
diff --git a/arts/modules/common/env_item_impl.cc b/arts/modules/common/env_item_impl.cc
index da3a6941..6bc960d8 100644
--- a/arts/modules/common/env_item_impl.cc
+++ b/arts/modules/common/env_item_impl.cc
@@ -16,7 +16,7 @@ Environment::Item_impl::~Item_impl()
 	arts_assert(_active == false);
 }
 
-Environment::Container Environment::Item_impl::tqparent()
+Environment::Container Environment::Item_impl::parent()
 {
 	Container p = _parent;
 	return p;
diff --git a/arts/modules/common/env_item_impl.h b/arts/modules/common/env_item_impl.h
index 4fcd1fc8..dbdca1f9 100644
--- a/arts/modules/common/env_item_impl.h
+++ b/arts/modules/common/env_item_impl.h
@@ -18,7 +18,7 @@ public:
 	~Item_impl();
 
 	bool active();
-	Container tqparent();
+	Container parent();
 	void setContainer(Container container);
 };
 }
diff --git a/arts/modules/common/env_mixeritem_impl.cc b/arts/modules/common/env_mixeritem_impl.cc
index db4bc18c..3e80e603 100644
--- a/arts/modules/common/env_mixeritem_impl.cc
+++ b/arts/modules/common/env_mixeritem_impl.cc
@@ -165,7 +165,7 @@ public:
 				Widget w = guiFactory.createGui((*channels)[i]);
 				if(!w.isNull())
 				{
-					w.tqparent(channel_hbox);
+					w.parent(channel_hbox);
 					w.show();
 					channelWidgets.push_back(w);
 				}
@@ -183,21 +183,21 @@ public:
 		if(!_item.isNull() && !vbox.isNull())
 		{
 			hbox = HBox();
-			hbox.tqparent(vbox);
+			hbox.parent(vbox);
 			hbox.show();
 
 			spinbox = SpinBox();
 			spinbox.caption(i18n("channels").utf8().data());
 			spinbox.min(0); spinbox.max(32);
 			spinbox.value(_item.channelCount());
-			spinbox.tqparent(hbox);
+			spinbox.parent(hbox);
 			spinbox.show();
 			connect(spinbox,"value_changed", _item, "channelCount");
 
 			name = LineEdit();
 			name.caption(i18n("name").utf8().data());
 			name.text(_item.name());
-			name.tqparent(hbox);
+			name.parent(hbox);
 			name.show();
 			connect(name,"text_changed", _item, "name");
 
@@ -212,12 +212,12 @@ public:
 			delete queryResults;
 			typebox.choices(choices);
 			typebox.value(_type);
-			typebox.tqparent(hbox);
+			typebox.parent(hbox);
 			typebox.show();
 			connect(typebox,"value_changed", _item, "type");
 
 			channel_hbox = HBox();
-			channel_hbox.tqparent(vbox);
+			channel_hbox.parent(vbox);
 			channel_hbox.show();
 
 			channelWidgets.clear();
@@ -320,14 +320,14 @@ public:
 			HBox hbox;
 			hbox.show();
 			hbox.width(330); hbox.height(50);
-			hbox.tqparent(vbox);
+			hbox.parent(vbox);
 			vbox._addChild(hbox,"hbox");
 
 			SpinBox spinbox;
 			spinbox.caption(i18n("channels").utf8().data());
 			spinbox.min(0); spinbox.max(32);
 			spinbox.value(mixerItem.channelCount());
-			spinbox.tqparent(hbox);
+			spinbox.parent(hbox);
 			spinbox.show();
 			connect(spinbox,"value_changed", mixerItem, "channelCount");
 			hbox._addChild(spinbox,"channelsWidget");
@@ -335,7 +335,7 @@ public:
 			LineEdit name;
 			name.caption(i18n("name").utf8().data());
 			name.caption(mixerItem.name());
-			name.tqparent(hbox);
+			name.parent(hbox);
 			name.show();
 			connect(name,"caption_changed", mixerItem, "name");
 			hbox._addChild(name,"nameWidget");
@@ -343,7 +343,7 @@ public:
 			HBox channel_hbox;
 			channel_hbox.show();
 			channel_hbox.width(330); hbox.height(450);
-			channel_hbox.tqparent(vbox);
+			channel_hbox.parent(vbox);
 			vbox._addChild(channel_hbox,"channel_hbox");
 
 			GenericGuiFactory gf;
@@ -353,7 +353,7 @@ public:
 			for(i = channels->begin(); i != channels->end(); i++)
 			{
 				Widget w = gf.createGui(*i);
-				w.tqparent(channel_hbox);
+				w.parent(channel_hbox);
 				channel_hbox._addChild(w,"channel");
 			}
 #endif
diff --git a/arts/modules/effects/fivebandmonocomplexeq_impl.cc b/arts/modules/effects/fivebandmonocomplexeq_impl.cc
index 827687e2..56ca6037 100644
--- a/arts/modules/effects/fivebandmonocomplexeq_impl.cc
+++ b/arts/modules/effects/fivebandmonocomplexeq_impl.cc
@@ -123,11 +123,11 @@ public:
 		Arts::Poti lowfreq; lowfreq.color( "grey" ); lowfreq.caption( i18n( "Low Freq" ).utf8().data() );
 		lowfreq.min( 20 ); lowfreq.max( 1000 );
 		lowfreq.value( ch.lowfreq() ); connect( lowfreq, "value_changed", ch, "lowfreq" );
-		lowfreq.tqparent( lowbox ); lowbox._addChild( lowfreq , "" );
+		lowfreq.parent( lowbox ); lowbox._addChild( lowfreq , "" );
 		Arts::Poti lowq; lowq.color( "grey" ); lowq.caption( i18n( "Low Q" ).utf8().data() );
 		lowq.min( 0.01 ); lowq.max( 10 );
 		lowq.value( ch.lowq() ); connect( lowq, "value_changed", ch, "lowq" );
-		lowq.tqparent( lowbox ); lowbox._addChild( lowq , "" );
+		lowq.parent( lowbox ); lowbox._addChild( lowq , "" );
 
 		Arts::Poti mid1gain; mid1gain.caption( i18n( "Mid1 Gain" ).utf8().data() );
 		mid1gain.min( -24 ); mid1gain.max( 24 );
@@ -140,11 +140,11 @@ public:
 		Arts::Poti mid1freq; mid1freq.color( "grey" ); mid1freq.caption( i18n( "Mid1 Freq" ).utf8().data() );
 		mid1freq.min( 20 ); mid1freq.max( 5000 );
 		mid1freq.value( ch.mid1freq() ); connect( mid1freq, "value_changed", ch, "mid1freq" );
-		mid1freq.tqparent( mid1box ); mid1box._addChild( mid1freq , "" );
+		mid1freq.parent( mid1box ); mid1box._addChild( mid1freq , "" );
 		Arts::Poti mid1q; mid1q.color(  "grey" ); mid1q.caption( i18n( "Mid1 Q" ).utf8().data() );
 		mid1q.min( 0.01 ); mid1q.max( 10 );
 		mid1q.value( ch.mid1q() ); connect( mid1q, "value_changed", ch, "mid1q" );
-		mid1q.tqparent( mid1box ); mid1box._addChild( mid1q , "" );
+		mid1q.parent( mid1box ); mid1box._addChild( mid1q , "" );
 
 		Arts::Poti mid2gain; mid2gain.caption( i18n( "Mid2 Gain" ).utf8().data() );
 		mid2gain.min( -24 ); mid2gain.max( 24 );
@@ -157,11 +157,11 @@ public:
 		Arts::Poti mid2freq; mid2freq.color( "grey" ); mid2freq.caption( i18n( "Mid2 Freq" ).utf8().data() );
 		mid2freq.min( 20 ); mid2freq.max( 10000 );
 		mid2freq.value( ch.mid2freq() ); connect( mid2freq, "value_changed", ch, "mid2freq" );
-		mid2freq.tqparent( mid2box ); mid2box._addChild( mid2freq , "" );
+		mid2freq.parent( mid2box ); mid2box._addChild( mid2freq , "" );
 		Arts::Poti mid2q; mid2q.color( "grey" ); mid2q.caption( i18n( "Mid2 Q" ).utf8().data() );
 		mid2q.min( 0.01 ); mid2q.max( 10 );
 		mid2q.value( ch.mid2q() ); connect( mid2q, "value_changed", ch, "mid2q" );
-		mid2q.tqparent( mid2box ); mid2box._addChild( mid2q , "" );
+		mid2q.parent( mid2box ); mid2box._addChild( mid2q , "" );
 
 		Arts::Poti mid3gain; mid3gain.caption( i18n( "Mid3 Gain" ).utf8().data() );
 		mid3gain.min( -24 ); mid3gain.max( 24 );
@@ -174,11 +174,11 @@ public:
 		Arts::Poti mid3freq; mid3freq.color( "grey" ); mid3freq.caption( i18n( "Mid3 Freq" ).utf8().data() );
 		mid3freq.min( 1000 ); mid3freq.max( 10000 );
 		mid3freq.value( ch.mid3freq() ); connect( mid3freq, "value_changed", ch, "mid3freq" );
-		mid3freq.tqparent( mid3box ); mid3box._addChild( mid3freq , "" );
+		mid3freq.parent( mid3box ); mid3box._addChild( mid3freq , "" );
 		Arts::Poti mid3q; mid3q.color( "grey" ); mid3q.caption( i18n( "Mid3 Q" ).utf8().data() );
 		mid3q.min( 0.01 ); mid3q.max( 10 );
 		mid3q.value( ch.mid3q() ); connect( mid3q, "value_changed", ch, "mid3q" );
-		mid3q.tqparent( mid3box ); mid3box._addChild( mid3q , "" );
+		mid3q.parent( mid3box ); mid3box._addChild( mid3q , "" );
 
 		Arts::Poti highgain; highgain.caption( i18n( "High Gain" ).utf8().data() );
 		highgain.min( -24 ); highgain.max( 24 );
@@ -191,11 +191,11 @@ public:
 		Arts::Poti highfreq; highfreq.color( "grey" ); highfreq.caption( i18n( "High Freq" ).utf8().data() );
 		highfreq.min( 5000 ); highfreq.max( 16000 );
 		highfreq.value( ch.highfreq() ); connect( highfreq, "value_changed", ch, "highfreq" );
-		highfreq.tqparent( highbox ); highbox._addChild( highfreq , "" );
+		highfreq.parent( highbox ); highbox._addChild( highfreq , "" );
 		Arts::Poti highq; highq.color( "grey" ); highq.caption( i18n( "High Q" ).utf8().data() );
 		highq.min( 0.01 ); highq.max( 10 );
 		highq.value( ch.highq() ); connect( highq, "value_changed", ch, "highq" );
-		highq.tqparent( highbox ); highbox._addChild( highq , "" );
+		highq.parent( highbox ); highbox._addChild( highq , "" );
 
 		hbox.addStretch( 100 );
 
diff --git a/arts/modules/effects/freeverbguifactory_impl.cc b/arts/modules/effects/freeverbguifactory_impl.cc
index 17878daa..7af1f471 100644
--- a/arts/modules/effects/freeverbguifactory_impl.cc
+++ b/arts/modules/effects/freeverbguifactory_impl.cc
@@ -58,7 +58,7 @@ Widget FreeverbGuiFactory_impl::createGui(Object object)
 	roomsize.color("red"); roomsize.min(0); roomsize.max(1);
 	roomsize.value(freeverb.roomsize());
 	roomsize.range(100);
-	roomsize.tqparent(hbox);
+	roomsize.parent(hbox);
 	roomsize.show();
 	connect(roomsize,"value_changed", freeverb, "roomsize");
 	hbox._addChild(roomsize,"roomsizeWidget");
@@ -68,7 +68,7 @@ Widget FreeverbGuiFactory_impl::createGui(Object object)
 	damp.color("red"); damp.min(0); damp.max(1);
 	damp.value(freeverb.damp());
 	damp.range(100);
-	damp.tqparent(hbox);
+	damp.parent(hbox);
 	damp.show();
 	connect(damp,"value_changed", freeverb, "damp");
 	hbox._addChild(damp,"dampWidget");
@@ -78,7 +78,7 @@ Widget FreeverbGuiFactory_impl::createGui(Object object)
 	wet.color("red"); wet.min(0); wet.max(1);
 	wet.value(freeverb.wet());
 	wet.range(100);
-	wet.tqparent(hbox);
+	wet.parent(hbox);
 	wet.show();
 	connect(wet,"value_changed", freeverb, "wet");
 	hbox._addChild(wet,"wetWidget");
@@ -88,7 +88,7 @@ Widget FreeverbGuiFactory_impl::createGui(Object object)
 	dry.color("red"); dry.min(0); dry.max(1);
 	dry.value(freeverb.dry());
 	dry.range(100);
-	dry.tqparent(hbox);
+	dry.parent(hbox);
 	dry.show();
 	connect(dry,"value_changed", freeverb, "dry");
 	hbox._addChild(dry,"dryWidget");
@@ -98,7 +98,7 @@ Widget FreeverbGuiFactory_impl::createGui(Object object)
 	width.color("red"); width.min(0); width.max(1);
 	width.value(freeverb.width());
 	width.range(100);
-	width.tqparent(hbox);
+	width.parent(hbox);
 	width.show();
 	connect(width,"value_changed", freeverb, "width");
 	hbox._addChild(width,"widthWidget");
diff --git a/arts/modules/effects/kstereovolumecontrolgui_impl.h b/arts/modules/effects/kstereovolumecontrolgui_impl.h
index 855c979c..28400f1e 100644
--- a/arts/modules/effects/kstereovolumecontrolgui_impl.h
+++ b/arts/modules/effects/kstereovolumecontrolgui_impl.h
@@ -86,7 +86,7 @@ public:
 	TQTimer* _timer;
 	Arts::KStereoVolumeControlGui_impl* _impl;
 public:
-	KStereoVolumeControlGui_EventMapper( Arts::KStereoVolumeControlGui_impl* impl, TQObject* tqparent, const char* name=0 ) : TQObject( tqparent,name ), _impl( impl ) {
+	KStereoVolumeControlGui_EventMapper( Arts::KStereoVolumeControlGui_impl* impl, TQObject* parent, const char* name=0 ) : TQObject( parent,name ), _impl( impl ) {
 		_timer = new TQTimer( this );
 		connect( _timer, TQT_SIGNAL( timeout() ), this, TQT_SLOT( slotTimerSignal() ) );
 	}
diff --git a/arts/modules/effects/synth_stereo_fir_equalizer_impl.cc b/arts/modules/effects/synth_stereo_fir_equalizer_impl.cc
index 86f7c1bb..ece106c2 100644
--- a/arts/modules/effects/synth_stereo_fir_equalizer_impl.cc
+++ b/arts/modules/effects/synth_stereo_fir_equalizer_impl.cc
@@ -186,7 +186,7 @@ Widget StereoFirEqualizerGuiFactory_impl::createGui(Object object)
 	vbox.show();
 
 	Graph g;
-	g.tqparent(vbox);
+	g.parent(vbox);
 	g.width(400);
 	g.height(230);
 	g.caption(i18n("a graph").utf8().data());
@@ -211,7 +211,7 @@ Widget StereoFirEqualizerGuiFactory_impl::createGui(Object object)
 	spinbox.caption(i18n("channels").utf8().data());
 	spinbox.min(3); spinbox.max(255);
 	spinbox.value(equalizer.taps());
-	spinbox.tqparent(vbox);
+	spinbox.parent(vbox);
 	spinbox.show();
 	connect(spinbox,"value_changed", equalizer, "taps");
 	vbox._addChild(spinbox,"spinbox");
diff --git a/arts/modules/effects/voiceremovalguifactory_impl.cc b/arts/modules/effects/voiceremovalguifactory_impl.cc
index 4a4011be..d4879b87 100644
--- a/arts/modules/effects/voiceremovalguifactory_impl.cc
+++ b/arts/modules/effects/voiceremovalguifactory_impl.cc
@@ -53,7 +53,7 @@ Widget VoiceRemovalGuiFactory_impl::createGui( Object object )
 	position.color( "grey" ); position.min( -1 ); position.max( 1 );
 	position.value( voiceremoval.position() );
 	position.range( 100 );
-	position.tqparent( hbox );
+	position.parent( hbox );
 	position.show();
 	connect( position, "value_changed", voiceremoval, "position" );
 	hbox._addChild( position, "positionWidget" );
@@ -64,7 +64,7 @@ Widget VoiceRemovalGuiFactory_impl::createGui( Object object )
 	freq.value( voiceremoval.frequency() );
 	freq.range( 400 );
 	freq.logarithmic( 2.0 );
-	freq.tqparent( hbox );
+	freq.parent( hbox );
 	freq.show();
 	connect( freq, "value_changed", voiceremoval, "frequency" );
 	hbox._addChild( freq, "freqWidget" );
diff --git a/arts/modules/synth/synth_cdelay_impl.cc b/arts/modules/synth/synth_cdelay_impl.cc
index 267daab8..28f4d12f 100644
--- a/arts/modules/synth/synth_cdelay_impl.cc
+++ b/arts/modules/synth/synth_cdelay_impl.cc
@@ -43,14 +43,14 @@ class Synth_CDELAY_impl : virtual public Synth_CDELAY_skel,
 {
 protected:
 	unsigned long _buffersize;
-	unsigned long _bittqmask;
+	unsigned long _bitmask;
 	float *_buffer; // holds the data to be delayed (variable size)
 	float _delaytime;
 	unsigned int _readpos;
 	unsigned int _writepos;
  
 public:
-	Synth_CDELAY_impl() : _buffersize( 0 ), _bittqmask( 0 ), _buffer( 0 ), _delaytime( 0 ), _readpos( 0 ), _writepos( 0 )
+	Synth_CDELAY_impl() : _buffersize( 0 ), _bitmask( 0 ), _buffer( 0 ), _delaytime( 0 ), _readpos( 0 ), _writepos( 0 )
 	{
 	}
 	
@@ -66,7 +66,7 @@ public:
 		_delaytime = newTime;
 		double n = ceil( log( double(_delaytime * samplingRateFloat )) / log( 2. ) );
 		unsigned long newbuffersize = (unsigned long)( pow( 2, n ) );
-		unsigned long newbittqmask = newbuffersize - 1;
+		unsigned long newbitmask = newbuffersize - 1;
 		if( newbuffersize != _buffersize )
 		{
 			float *newbuffer = new float[newbuffersize];
@@ -74,24 +74,24 @@ public:
 				for( unsigned long i = 0; i < _buffersize; i++ ) {
 					newbuffer[i] = _buffer[_writepos];
 					_writepos++;
-					_writepos &= newbittqmask;
+					_writepos &= newbitmask;
 				}
 				for( unsigned long i = _buffersize; i < newbuffersize; i++ )
 					newbuffer[i] = 0;
 			} else {
 				_writepos -= newbuffersize;
-				_writepos &= newbittqmask;
+				_writepos &= newbitmask;
 				for( unsigned long i = 0; i < newbuffersize; i++ ) {
 					newbuffer[i] = _buffer[_writepos];
 					_writepos++;
-					_writepos &= newbittqmask;
+					_writepos &= newbitmask;
 				}
 			}
 			_buffer = newbuffer;
 			_buffersize = newbuffersize;
-			_bittqmask = newbittqmask;
+			_bitmask = newbitmask;
 		}
-		_readpos = (unsigned long)rint( _writepos - _delaytime * samplingRateFloat ) & _bittqmask;
+		_readpos = (unsigned long)rint( _writepos - _delaytime * samplingRateFloat ) & _bitmask;
 		time_changed( _delaytime );
 	}
 
@@ -113,9 +113,9 @@ public:
 			_buffer[_writepos] = invalue[i];
 			outvalue[i] = _buffer[_readpos];
 			_readpos++;
-			_readpos &= _bittqmask;
+			_readpos &= _bitmask;
 			_writepos++;
-			_writepos &= _bittqmask;
+			_writepos &= _bitmask;
 		}
 	}
 };
diff --git a/arts/modules/synth/synth_delay_impl.cc b/arts/modules/synth/synth_delay_impl.cc
index 57285118..92c23fd1 100644
--- a/arts/modules/synth/synth_delay_impl.cc
+++ b/arts/modules/synth/synth_delay_impl.cc
@@ -56,13 +56,13 @@ class Synth_DELAY_impl : virtual public Synth_DELAY_skel,
 {
 protected:
 	unsigned long _buffersize;
-	unsigned long _bittqmask;
+	unsigned long _bitmask;
 	float * _buffer;
 	float _maxdelay;
 	unsigned int _writepos;
  
 public:
-	Synth_DELAY_impl() : _buffersize( 0 ), _bittqmask( 0 ), _buffer( 0 ), _maxdelay( 0 ), _writepos( 0 )
+	Synth_DELAY_impl() : _buffersize( 0 ), _bitmask( 0 ), _buffer( 0 ), _maxdelay( 0 ), _writepos( 0 )
 	{
 		maxdelay( 1 ); // take a one second buffer if nothing else is specified
 	}
@@ -85,15 +85,15 @@ public:
 		{
 			double int_pos;
 			double error = modf( time[i] * samplingRateFloat, &int_pos );
-			unsigned long readpos1 = ( _writepos - (unsigned long)(int_pos) ) & _bittqmask;
-			unsigned long readpos2 = ( readpos1 - 1 ) & _bittqmask; // Shouldn't this be +1? (mkretz)
+			unsigned long readpos1 = ( _writepos - (unsigned long)(int_pos) ) & _bitmask;
+			unsigned long readpos2 = ( readpos1 - 1 ) & _bitmask; // Shouldn't this be +1? (mkretz)
 			// No, it's right this way:
 			// ( 1 - error ) needs to be multiplied with the second
 			// sample; error with the first
 			_buffer[_writepos] = invalue[i];
 			outvalue[i] = _buffer[readpos1] * ( 1 - error ) + _buffer[readpos2] * error;
 			_writepos++;
-			_writepos &= _bittqmask;
+			_writepos &= _bitmask;
 		}
 	}
 
@@ -106,7 +106,7 @@ public:
 		_maxdelay = newmaxdelay;
 		double n = ceil( log( double(_maxdelay * samplingRateFloat) ) / log( 2. ) );
 		unsigned long newbuffersize = (unsigned long)( pow( 2, n ) );
-		unsigned long newbittqmask = newbuffersize - 1;
+		unsigned long newbitmask = newbuffersize - 1;
 		if( newbuffersize != _buffersize )
 		{
 			float *newbuffer = new float[newbuffersize];
@@ -114,22 +114,22 @@ public:
 				for( unsigned long i = 0; i < _buffersize; i++ ) {
 					newbuffer[i] = _buffer[_writepos];
 					_writepos++;
-					_writepos &= newbittqmask;
+					_writepos &= newbitmask;
 				}
 				for( unsigned long i = _buffersize; i < newbuffersize; i++ )
 					newbuffer[i] = 0;
 			} else {
 				_writepos -= newbuffersize;
-				_writepos &= newbittqmask;
+				_writepos &= newbitmask;
 				for( unsigned long i = 0; i < newbuffersize; i++ ) {
 					newbuffer[i] = _buffer[_writepos];
 					_writepos++;
-					_writepos &= newbittqmask;
+					_writepos &= newbitmask;
 				}
 			}
 			_buffer = newbuffer;
 			_buffersize = newbuffersize;
-			_bittqmask = newbittqmask;
+			_bitmask = newbitmask;
 		}
 		maxdelay_changed( _maxdelay );
 	}         
diff --git a/arts/runtime/artsbuilder.idl b/arts/runtime/artsbuilder.idl
index 7fe75949..2da25a68 100644
--- a/arts/runtime/artsbuilder.idl
+++ b/arts/runtime/artsbuilder.idl
@@ -76,11 +76,11 @@ module Arts {
 
 	interface PortDesc {
 		// internal:
-		void constructor(ModuleDesc tqparent, string name, PortType type);
+		void constructor(ModuleDesc parent, string name, PortType type);
 
 		// ID is guaranteed to be unique in the structure the port belongs to
 		readonly attribute long ID;
-		readonly attribute ModuleDesc tqparent;
+		readonly attribute ModuleDesc parent;
 
 		// Name is guaranteed to be unique for each module (no two in/out-
 		// ports with the same name allowed)
@@ -123,11 +123,11 @@ module Arts {
 
 	interface ModuleDesc {
 		// internal
-		void constructor(StructureDesc tqparent, ModuleInfo info);
+		void constructor(StructureDesc parent, ModuleInfo info);
 
 		// ID is guaranteed to be unique in the structure the module belongs to
 		readonly attribute long ID;
-		readonly attribute StructureDesc tqparent;
+		readonly attribute StructureDesc parent;
 
 		readonly attribute string name;
 		readonly attribute sequence<PortDesc> ports;
@@ -184,7 +184,7 @@ module Arts {
 
 	interface StructurePortDesc : PortDesc {
 		// internal
-		void constructor(StructureDesc tqparent, string name, PortType type);
+		void constructor(StructureDesc parent, string name, PortType type);
 
 		// Position: how the port is positioned when the structure is used
 		// as module - 0 is leftmost, higher numbers are more right
@@ -192,7 +192,7 @@ module Arts {
 		readonly attribute StructureDesc parentStructure;
 
 		// if the port is associated with an inherited interface of the
-		// tqparent structure, then it should be setup here
+		// parent structure, then it should be setup here
 		attribute string inheritedInterface;
 	
 		boolean moveTo(long x, long y);	// returns true when successful
diff --git a/arts/runtime/structurebuilder_impl.cc b/arts/runtime/structurebuilder_impl.cc
index c2e217e8..43e5485c 100644
--- a/arts/runtime/structurebuilder_impl.cc
+++ b/arts/runtime/structurebuilder_impl.cc
@@ -96,7 +96,7 @@ ModuleDef StructureBuilder_impl::createTypeInfo(StructureDesc structure)
 	{
 		const Arts::PortType& type = pi->type();
 
-		// if we inherited the port from a tqparent interface, we don't need to
+		// if we inherited the port from a parent interface, we don't need to
 		// list it in our interface description
 		if(pi->inheritedInterface().empty())
 		{
@@ -236,12 +236,12 @@ Structure_impl::Structure_impl(StructureDesc structureDesc,
 
 				for(ci = connections->begin(); ci != connections->end(); ci++)
 				{
-					if(!ci->tqparent().isNull())	// structureport otherwise
+					if(!ci->parent().isNull())	// structureport otherwise
 					{
-						Object& dest = moduleMap[ci->tqparent().ID()];
+						Object& dest = moduleMap[ci->parent().ID()];
 #ifdef STRUCTBUILDER_DEBUG
 						cout << "connect " << mi->name() << "." << pi->name()
-					     	 << " to " << ci->tqparent().name()
+					     	 << " to " << ci->parent().name()
 							 << "." << ci->name() << endl;
 #endif
 						connect(object,pd.name(),dest,ci->name());
@@ -271,10 +271,10 @@ Structure_impl::Structure_impl(StructureDesc structureDesc,
 
 			for(ci = connections->begin(); ci != connections->end(); ci++)
 			{
-				Object& dest = moduleMap[ci->tqparent().ID()];
+				Object& dest = moduleMap[ci->parent().ID()];
 #ifdef STRUCTBUILDER_DEBUG
 				cout << "virtualize " << pi->name()
-				     << " to " << ci->tqparent().name() << "." << ci->name()
+				     << " to " << ci->parent().name() << "." << ci->name()
 					 << endl;
 #endif
 
diff --git a/arts/runtime/structures_impl.cc b/arts/runtime/structures_impl.cc
index 5c392e91..7c5a5e05 100644
--- a/arts/runtime/structures_impl.cc
+++ b/arts/runtime/structures_impl.cc
@@ -32,11 +32,11 @@ public:
 	~PortDesc_impl();
 
 	inline PortDesc self() { return PortDesc::_from_base(_copy()); }
-	void constructor(ModuleDesc tqparent, const string& name, const PortType& type);
+	void constructor(ModuleDesc parent, const string& name, const PortType& type);
 
 	void disconnectAll();
 	long ID();
-	ModuleDesc tqparent();
+	ModuleDesc parent();
 	string name();
 	PortType type();
 	bool isConnected();
@@ -78,7 +78,7 @@ private:
 
 public:
 	long ID();
-	StructureDesc tqparent();
+	StructureDesc parent();
 	string name();
 	vector<PortDesc> *ports();
 	long height();
@@ -86,7 +86,7 @@ public:
 	long x();
 	long y();
 	bool moveTo( long x, long y );
-	void constructor( StructureDesc tqparent, const ModuleInfo& info );
+	void constructor( StructureDesc parent, const ModuleInfo& info );
 
 	void loadFromList(const vector<string>& list);
 	vector<string> *saveToList();
@@ -155,7 +155,7 @@ protected:
 		return StructurePortDesc::_from_base(_copy());
 	}
 public:
-	void constructor(StructureDesc tqparent, const string& name,
+	void constructor(StructureDesc parent, const string& name,
 					const PortType& type);
 	~StructurePortDesc_impl();
 
@@ -192,13 +192,13 @@ REGISTER_IMPLEMENTATION(StructurePortDesc_impl);
 #define pstat \
 	printf("port name %s, direction %s, id %d\n",_Name.c_str(),dname(_Type.direction),_ID);
 
-void PortDesc_impl::constructor(ModuleDesc tqparent, const string& name,
+void PortDesc_impl::constructor(ModuleDesc parent, const string& name,
 													const PortType& type)
 {
 #if 0
-	if(tqparent)
+	if(parent)
 	{
-		char * pname = tqparent->Name();
+		char * pname = parent->Name();
 		describe("PortDesc."+string(pname)+string(".")+name);
 	}
 	else
@@ -208,14 +208,14 @@ void PortDesc_impl::constructor(ModuleDesc tqparent, const string& name,
 #endif
 	_name = name;
 	_type = type;
-	_parent = tqparent;
+	_parent = parent;
 	_isConnected = false;
 	_hasValue = false;
 	_value.type = _type.dataType;
 
-	if(!tqparent.isNull())
+	if(!parent.isNull())
 	{
-		StructureDesc sd = tqparent.tqparent();
+		StructureDesc sd = parent.parent();
 		_ID = sd.obtainID();
 	}
 	// else: assume that some smart object which derives from us will set the ID accordingly
@@ -276,7 +276,7 @@ long PortDesc_impl::ID()
 	return _ID; 
 }
 
-ModuleDesc PortDesc_impl::tqparent()
+ModuleDesc PortDesc_impl::parent()
 {
 	return _parent; 
 }
@@ -468,11 +468,11 @@ void PortDesc_impl::disconnectFrom( PortDesc port )
 
 	_isConnected = !_connections.empty();
 
-	ModuleDesc tqparent = _parent;
-	if(tqparent.isNull())
+	ModuleDesc parent = _parent;
+	if(parent.isNull())
 		artsdebug("_Parent = <some structure>, isConnected = %d\n",_isConnected);
 	else
-		artsdebug("_Parent = %s, isConnected = %d\n",tqparent.name().c_str(),_isConnected);
+		artsdebug("_Parent = %s, isConnected = %d\n",parent.name().c_str(),_isConnected);
 
 	if(found)
 		port.disconnectFrom(self());
@@ -484,7 +484,7 @@ long ModuleDesc_impl::ID()
 	return _ID; 
 }
 
-StructureDesc ModuleDesc_impl::tqparent()
+StructureDesc ModuleDesc_impl::parent()
 {
 	return _parent; 
 }
@@ -549,14 +549,14 @@ long StructureDesc_impl::height()
  * Query the module for it's paramenters
  */
 
-void ModuleDesc_impl::constructor( StructureDesc tqparent,
+void ModuleDesc_impl::constructor( StructureDesc parent,
 								const Arts::ModuleInfo& info )
 {
 	_name = info.name;
 	_x = -1;		// no position assigned
 	_y = -1;
-	_ID = tqparent.obtainID();
-	_parent = tqparent;
+	_ID = parent.obtainID();
+	_parent = parent;
 	_isInterface = info.isInterface;
 	_isStructure = info.isStructure;
 
@@ -1134,12 +1134,12 @@ void StructureDesc_impl::moveStructurePortDesc(StructurePortDesc
 	portdesc.internalSetPosition(newposition);
 }
 
-void StructurePortDesc_impl::constructor(StructureDesc tqparent,
+void StructurePortDesc_impl::constructor(StructureDesc parent,
 								const string& name, const PortType& type)
 {
 	PortDesc_impl::constructor(ModuleDesc::null(),name,type);
-	_parentStructure = tqparent;
-	_ID = tqparent.obtainID();
+	_parentStructure = parent;
+	_ID = parent.obtainID();
 	_x = 0;
 	_y = 0;
 	_position = 0;
@@ -1167,18 +1167,18 @@ long StructurePortDesc_impl::position()
 
 void StructurePortDesc_impl::lowerPosition()
 {
-	StructureDesc tqparent = _parentStructure;		// weak reference
+	StructureDesc parent = _parentStructure;		// weak reference
 
-	if(!tqparent.isNull())
-		tqparent.moveStructurePortDesc(self(), _position-1);
+	if(!parent.isNull())
+		parent.moveStructurePortDesc(self(), _position-1);
 }
 
 void StructurePortDesc_impl::raisePosition()
 {
-	StructureDesc tqparent = _parentStructure;		// weak reference
+	StructureDesc parent = _parentStructure;		// weak reference
 
-	if(!tqparent.isNull())
-		tqparent.moveStructurePortDesc(self(), _position+1);
+	if(!parent.isNull())
+		parent.moveStructurePortDesc(self(), _position+1);
 }
 
 void StructurePortDesc_impl::rename(const string& newname)
diff --git a/arts/tools/artsactions.cpp b/arts/tools/artsactions.cpp
index 9075f87e..6f07a322 100644
--- a/arts/tools/artsactions.cpp
+++ b/arts/tools/artsactions.cpp
@@ -36,8 +36,8 @@
 #include "environmentview.h"
 #include "mediatypesview.h"
 
-ArtsActions::ArtsActions( KArtsServer* server, KActionCollection* col, TQWidget* tqparent, const char* name )
-  : TQObject( tqparent,name )
+ArtsActions::ArtsActions( KArtsServer* server, KActionCollection* col, TQWidget* parent, const char* name )
+  : TQObject( parent,name )
   , _kartsserver( server )
   , _actioncollection( col )
   , _a_sv( 0 ), _a_am( 0 ), _a_asv( 0 ), _a_mmv( 0 ), _a_ev( 0 ), _a_mtv( 0 )
diff --git a/arts/tools/artsactions.h b/arts/tools/artsactions.h
index b6f77839..d28edd33 100644
--- a/arts/tools/artsactions.h
+++ b/arts/tools/artsactions.h
@@ -48,7 +48,7 @@ public:
 
 		@param artsserver a pointer to a existing KArtsServer. If 0 a new is created.
 		@param actioncollection the KActionCollection all the actions should belong to. Names of the actions are then: artssupport_*
-		@param qwidget the tqparent TQWidget
+		@param qwidget the parent TQWidget
 		@param name the name of the object
 	*/
 	ArtsActions( KArtsServer* artsserver, KActionCollection* actioncollection, TQWidget* qwidget, const char* name=0 );
diff --git a/arts/tools/artscontrolapplet.cpp b/arts/tools/artscontrolapplet.cpp
index 490366d1..f59bc9ff 100644
--- a/arts/tools/artscontrolapplet.cpp
+++ b/arts/tools/artscontrolapplet.cpp
@@ -29,18 +29,18 @@
 
 extern "C"
 {
-  KDE_EXPORT KPanelApplet* init( TQWidget *tqparent, const TQString configFile)
+  KDE_EXPORT KPanelApplet* init( TQWidget *parent, const TQString configFile)
   {
     KGlobal::locale()->insertCatalogue("artscontrol");
     return new ArtsControlApplet(configFile, KPanelApplet::Normal,
                       KPanelApplet::About /*| KPanelApplet::Help | KPanelApplet::Preferences*/,
-                      tqparent, "artscontrolapplet");
+                      parent, "artscontrolapplet");
   }
 }
 
-ArtsControlApplet::ArtsControlApplet(const TQString& configFile, Type type, int actions, TQWidget *tqparent, const char *name) : KPanelApplet(configFile, type, actions, tqparent, name)
+ArtsControlApplet::ArtsControlApplet(const TQString& configFile, Type type, int actions, TQWidget *parent, const char *name) : KPanelApplet(configFile, type, actions, parent, name)
 {
-	//kdDebug()<<"ArtsControlApplet::ArtsControlApplet( const TQString& "<<configFile<<", Type "<<type<<", int "<<actions<<", TQWidget* "<<tqparent<<", const char* "<<name<<" )"<<endl;
+	//kdDebug()<<"ArtsControlApplet::ArtsControlApplet( const TQString& "<<configFile<<", Type "<<type<<", int "<<actions<<", TQWidget* "<<parent<<", const char* "<<name<<" )"<<endl;
 	// Get the current application configuration handle
 	ksConfig = config();
 
diff --git a/arts/tools/artscontrolapplet.h b/arts/tools/artscontrolapplet.h
index ab683464..e1722ebf 100644
--- a/arts/tools/artscontrolapplet.h
+++ b/arts/tools/artscontrolapplet.h
@@ -39,7 +39,7 @@ public:
 	* @param configFile The configFile handed over in the factory function.
 	* @param Type The applet @ref type().
 	* @param actions Standard RMB menu actions supported by the applet (see @ref action() ).
-	* @param tqparent The pointer to the tqparent widget handed over in the factory function.
+	* @param parent The pointer to the parent widget handed over in the factory function.
 	* @param name A TQt object name for your applet.
 	**/
 	ArtsControlApplet(const TQString& configFile, Type t = Normal, int = 0,
diff --git a/arts/tools/artscontrolapplet_private.h b/arts/tools/artscontrolapplet_private.h
index 2f7c553d..bddc0728 100644
--- a/arts/tools/artscontrolapplet_private.h
+++ b/arts/tools/artscontrolapplet_private.h
@@ -66,9 +66,9 @@ public:
 	KAction *_showSV, *_showSVinline, *_showAM, *_showArtstqStatus, *_showMidiManager, *_showEnvironment, *_showMediaTypes, *_moreBars, *_lessBars;
 	KAction *_styleNormalBars, *_styleFireBars, *_styleLineBars, *_styleLEDs, *_styleAnalog, *_styleSmall;
 
-	ArtsControlAppletPrivate( ArtsControlApplet *tqparent )
-	    : TQObject(tqparent)
-	    , _parent( tqparent )
+	ArtsControlAppletPrivate( ArtsControlApplet *parent )
+	    : TQObject(parent)
+	    , _parent( parent )
 	    , barts( false )
 	    , bInUpdate( false )
 	{
@@ -78,7 +78,7 @@ public:
 		if( barts ) volume = arts->server().outVolume();
 		svinline=0;
 
-		_artsactions = new ArtsActions( arts, 0, tqparent );
+		_artsactions = new ArtsActions( arts, 0, parent );
 
 		menu = new KPopupMenu( 0 );
 		_showSV = _artsactions->actionScopeView();
diff --git a/arts/tools/audiomanager.cpp b/arts/tools/audiomanager.cpp
index 73debf80..439ab191 100644
--- a/arts/tools/audiomanager.cpp
+++ b/arts/tools/audiomanager.cpp
@@ -37,7 +37,7 @@ using namespace std;
  * as this is an 1:1 port of an old arts-0.3.4.1 artsbuilable visual widget,
  * you'll see some porting artefacts, and it's not elegance itself ;)
  */
-Gui_AUDIO_MANAGER::Gui_AUDIO_MANAGER( TQWidget* tqparent, const char* name ) : Template_ArtsView( tqparent,name )
+Gui_AUDIO_MANAGER::Gui_AUDIO_MANAGER( TQWidget* parent, const char* name ) : Template_ArtsView( parent,name )
 {
 	this->setCaption( i18n( "Audio Manager" ) );
 	this->setIcon( MainBarIcon( "artsaudiomanager", 32 ) );
@@ -72,14 +72,14 @@ void Gui_AUDIO_MANAGER::widgetDestroyed(TQWidget *widget)
 }
 #endif
 
-void Gui_AUDIO_MANAGER::setParent(TQWidget *tqparent, TQBoxLayout * /*tqlayout*/)
+void Gui_AUDIO_MANAGER::setParent(TQWidget *parent, TQBoxLayout * /*tqlayout*/)
 {
 /************************************************************************
  * From Gui_INSTRUMENT_MAPPER:
  *
- * I am still not sure wether this kind of putting yourself into a tqparent
+ * I am still not sure wether this kind of putting yourself into a parent
  * widget (with own tqlayout etc.) is a good idea (there may not even be
- * a singe call to setParent, because there is no tqparent).
+ * a singe call to setParent, because there is no parent).
  *
  * But the "how to write aRts widgets"-stuff will need some experiments,
  * so lets try that method...
@@ -90,12 +90,12 @@ void Gui_AUDIO_MANAGER::setParent(TQWidget *tqparent, TQBoxLayout * /*tqlayout*/
  * else would be appropriate. Check that. FIXME
  ************************************************************************/
 
-	TQVBoxLayout *maintqlayout = new TQVBoxLayout(tqparent);
+	TQVBoxLayout *maintqlayout = new TQVBoxLayout(parent);
 	/*TQHBoxLayout *contentstqlayout = new TQHBoxLayout;*/
 
 // list
 
-	listview = new KListView(tqparent);
+	listview = new KListView(parent);
 
 	listview->addColumn(i18n("Title"),175);
 	listview->addColumn(i18n("Type"),50);
@@ -110,7 +110,7 @@ void Gui_AUDIO_MANAGER::setParent(TQWidget *tqparent, TQBoxLayout * /*tqlayout*/
 
 	maintqlayout->activate();
 	//maintqlayout->freeze();
-	ParentWidget = tqparent;
+	ParentWidget = parent;
 }
 
 void Gui_AUDIO_MANAGER::tick()
@@ -178,8 +178,8 @@ void GuiAudioManagerProxy::edit(TQListViewItem *item)
 	gim->edit(item);
 }
 
-AudioManagerItem::AudioManagerItem(TQListView *tqparent, TQString a,
-         TQString b, TQString c, long ID) :TQListViewItem(tqparent,a,b,c)
+AudioManagerItem::AudioManagerItem(TQListView *parent, TQString a,
+         TQString b, TQString c, long ID) :TQListViewItem(parent,a,b,c)
 {
 	_ID = ID;
 }
diff --git a/arts/tools/audiomanager.h b/arts/tools/audiomanager.h
index 5a23092d..6f86778e 100644
--- a/arts/tools/audiomanager.h
+++ b/arts/tools/audiomanager.h
@@ -71,7 +71,7 @@ public slots:
 class AudioManagerItem : public TQListViewItem {
 	long _ID;
 public:
-	AudioManagerItem(TQListView *tqparent, TQString a, TQString b,
+	AudioManagerItem(TQListView *parent, TQString a, TQString b,
 			              TQString c, long ID);
 	~AudioManagerItem();
 
diff --git a/arts/tools/choosebusdlg.cpp b/arts/tools/choosebusdlg.cpp
index a4f96ba5..29a1bb69 100644
--- a/arts/tools/choosebusdlg.cpp
+++ b/arts/tools/choosebusdlg.cpp
@@ -42,8 +42,8 @@ static void min_size(TQWidget *w) {
   w->setMinimumSize(w->tqsizeHint());
 }
 
-ChooseBusDlg::ChooseBusDlg(TQWidget *tqparent)
-	: KDialog(tqparent,"X", TRUE)
+ChooseBusDlg::ChooseBusDlg(TQWidget *parent)
+	: KDialog(parent,"X", TRUE)
 	, _newbusitemindex( -1 )
 {
 	setCaption(i18n("Choose Bus"));
diff --git a/arts/tools/choosebusdlg.h b/arts/tools/choosebusdlg.h
index 9ba29b8a..13312651 100644
--- a/arts/tools/choosebusdlg.h
+++ b/arts/tools/choosebusdlg.h
@@ -36,7 +36,7 @@ class ChooseBusDlg :public KDialog {
 
 	int _newbusitemindex;
 public:
-	ChooseBusDlg(TQWidget *tqparent);
+	ChooseBusDlg(TQWidget *parent);
 
 public slots:
 	TQString result();
diff --git a/arts/tools/environmentview.cpp b/arts/tools/environmentview.cpp
index 0ba42a7f..f62a5c06 100644
--- a/arts/tools/environmentview.cpp
+++ b/arts/tools/environmentview.cpp
@@ -61,7 +61,7 @@ public:
 	}
 };
 
-EnvironmentView::EnvironmentView( Container container, TQWidget* tqparent, const char* name ) : Template_ArtsView( tqparent,name ), container(container)
+EnvironmentView::EnvironmentView( Container container, TQWidget* parent, const char* name ) : Template_ArtsView( parent,name ), container(container)
 {
 	this->setCaption( i18n( "Environment" ) );
 	this->setIcon( MainBarIcon( "artsenvironment", 32 ) );
diff --git a/arts/tools/fftscopeview.cpp b/arts/tools/fftscopeview.cpp
index 1d5c5345..ab15dc59 100644
--- a/arts/tools/fftscopeview.cpp
+++ b/arts/tools/fftscopeview.cpp
@@ -37,8 +37,8 @@
 using namespace std;
 using namespace Arts;
 
-FFTScopeView::FFTScopeView( SimpleSoundServer server, TQWidget* tqparent )
-	: Template_ArtsView( tqparent )
+FFTScopeView::FFTScopeView( SimpleSoundServer server, TQWidget* parent )
+	: Template_ArtsView( parent )
 	, server( server )
 	, scopeData( 0 )
 {
diff --git a/arts/tools/levelmeters.cpp b/arts/tools/levelmeters.cpp
index ae7834a8..08d9099b 100644
--- a/arts/tools/levelmeters.cpp
+++ b/arts/tools/levelmeters.cpp
@@ -7,8 +7,8 @@
 
 const int PeakBar::peakMillis=1500;
 
-PeakBar::PeakBar(TQWidget *tqparent)
-	: ACLevelMeter(tqparent)
+PeakBar::PeakBar(TQWidget *parent)
+	: ACLevelMeter(parent)
 	, maxValue( 0.0f )
 	, minValue( 0.0f )
 {
@@ -109,8 +109,8 @@ void PeakBar::setValue(float f) {
 
 // -------------------------------------------------------------
 
-PeakLevelMeters::PeakLevelMeters(TQWidget *tqparent):
-	StereoLevelMeter(tqparent), left(this), right(this), scaleView(this)
+PeakLevelMeters::PeakLevelMeters(TQWidget *parent):
+	StereoLevelMeter(parent), left(this), right(this), scaleView(this)
 {
 	TQBoxLayout *tqlayout= new TQHBoxLayout(this);
 	tqlayout->addWidget(&left);
@@ -142,7 +142,7 @@ void PeakLevelMeters::setValues(float leftVal, float rightVal) {
 	right.setValue(f);
 }
 
-ScaleView::ScaleView(TQWidget *tqparent): TQFrame(tqparent) {
+ScaleView::ScaleView(TQWidget *parent): TQFrame(parent) {
 	font.setPixelSize(10);
 	tqsetSizePolicy(TQSizePolicy(TQSizePolicy::Fixed, TQSizePolicy::Preferred));
 }
@@ -187,7 +187,7 @@ void ScaleView::drawContents(TQPainter *p) {
 
 // -------------------------------------------------------------
 
-LedMeter::LedMeter(TQWidget *tqparent, bool blueState) : ACLevelMeter(tqparent) {
+LedMeter::LedMeter(TQWidget *parent, bool blueState) : ACLevelMeter(parent) {
 	setBackgroundColor(black);
 	TQBoxLayout * l = new TQVBoxLayout( this );
 	l->setAutoAdd(TRUE);
@@ -223,8 +223,8 @@ void LedMeter::setValue(float f)
 
 // -------------------------------------------------------------
 
-StereoLedMeters::StereoLedMeters(TQWidget *tqparent)
-	: StereoLevelMeter(tqparent), left(this), right(this)
+StereoLedMeters::StereoLedMeters(TQWidget *parent)
+	: StereoLevelMeter(parent), left(this), right(this)
 {
 	TQBoxLayout *tqlayout= new TQHBoxLayout(this);
 	tqlayout->addWidget(&left);
diff --git a/arts/tools/levelmeters.h b/arts/tools/levelmeters.h
index 64c41c0b..8046d745 100644
--- a/arts/tools/levelmeters.h
+++ b/arts/tools/levelmeters.h
@@ -46,7 +46,7 @@ class ACLevelMeter : public TQFrame {
 	Q_OBJECT
   TQ_OBJECT
 public:
-	ACLevelMeter(TQWidget *tqparent): TQFrame(tqparent) {}
+	ACLevelMeter(TQWidget *parent): TQFrame(parent) {}
 public slots:
 	virtual void setValue(float f) = 0;
 };
@@ -58,7 +58,7 @@ class StereoLevelMeter : public TQFrame {
 	Q_OBJECT
   TQ_OBJECT
 public:
-	StereoLevelMeter(TQWidget *tqparent): TQFrame(tqparent) {}
+	StereoLevelMeter(TQWidget *parent): TQFrame(parent) {}
 public slots:
 	virtual void setValues(float left, float right) = 0;
 };
@@ -92,7 +92,7 @@ protected:
 	void frameChanged();
 	
 public:
-	PeakBar(TQWidget *tqparent);
+	PeakBar(TQWidget *parent);
 	
 	TQSize tqsizeHint() const;
 
@@ -111,7 +111,7 @@ protected:
 	int dbRange;
 	int upperMargin, lowerMargin;
 public:
-	ScaleView(TQWidget *tqparent);
+	ScaleView(TQWidget *parent);
 	void setDbRange(int db);
 	void setScaleMargins(int margins) { upperMargin= margins; lowerMargin=margins; }
 	TQSize tqsizeHint() const;
@@ -132,7 +132,7 @@ protected:
 	ScaleView scaleView;
 
 public:
-	PeakLevelMeters(TQWidget *tqparent);
+	PeakLevelMeters(TQWidget *parent);
 
 public slots:
 	void setValues(float leftVal, float rightVal);
@@ -153,7 +153,7 @@ protected:
 	KLed *leds[12];
 
 public:
-	LedMeter(TQWidget *tqparent, bool blueState = false);
+	LedMeter(TQWidget *parent, bool blueState = false);
 	void setValue(float f);
 };
 
@@ -167,7 +167,7 @@ protected:
 	LedMeter left, right;
 	
 public:
-	StereoLedMeters(TQWidget *tqparent);
+	StereoLedMeters(TQWidget *parent);
 public slots:
 	void setValues(float left, float right);
 };
diff --git a/arts/tools/main.cpp b/arts/tools/main.cpp
index 5492f38a..62b3668a 100644
--- a/arts/tools/main.cpp
+++ b/arts/tools/main.cpp
@@ -82,7 +82,7 @@ FreeVerbView::~FreeVerbView() {
 }
 
 
-VControl::VControl( KArtsServer* artsserver, TQWidget *tqparent) : TQFrame(tqparent)
+VControl::VControl( KArtsServer* artsserver, TQWidget *parent) : TQFrame(parent)
 	, freeVerbView(0)
 	, server( artsserver )
 {
diff --git a/arts/tools/main.h b/arts/tools/main.h
index 3b52dadb..41bcccdd 100644
--- a/arts/tools/main.h
+++ b/arts/tools/main.h
@@ -79,7 +79,7 @@ protected:
 	TQBoxLayout *boxLayout;
 
 public:
-	VControl( KArtsServer*, TQWidget *tqparent);
+	VControl( KArtsServer*, TQWidget *parent);
 	~VControl();
 
 public slots:
diff --git a/arts/tools/mediatypesview.cpp b/arts/tools/mediatypesview.cpp
index fb8938d7..9353cda6 100644
--- a/arts/tools/mediatypesview.cpp
+++ b/arts/tools/mediatypesview.cpp
@@ -33,7 +33,7 @@
 using namespace std;
 using namespace Arts;
 
-MediaTypesView::MediaTypesView( TQWidget* tqparent, const char* name ) : Template_ArtsView( tqparent,name )
+MediaTypesView::MediaTypesView( TQWidget* parent, const char* name ) : Template_ArtsView( parent,name )
 {
 	this->setCaption( i18n( "Available Media Types" ) );
 	this->setIcon( MainBarIcon( "artsmediatypes", 32 ) );
diff --git a/arts/tools/midiinstdlg.cpp b/arts/tools/midiinstdlg.cpp
index 339cafa6..8fe922b7 100644
--- a/arts/tools/midiinstdlg.cpp
+++ b/arts/tools/midiinstdlg.cpp
@@ -63,8 +63,8 @@ static TQStringList listFiles(TQString directory, TQString extension)
 	return result;
 }
 
-MidiInstDlg::MidiInstDlg(TQWidget *tqparent)
-	:TQDialog(tqparent,"instrument",TRUE)
+MidiInstDlg::MidiInstDlg(TQWidget *parent)
+	:TQDialog(parent,"instrument",TRUE)
 {
 	TQVBoxLayout *maintqlayout = new TQVBoxLayout(this);
 
diff --git a/arts/tools/midiinstdlg.h b/arts/tools/midiinstdlg.h
index 0e425225..52b617ef 100644
--- a/arts/tools/midiinstdlg.h
+++ b/arts/tools/midiinstdlg.h
@@ -31,7 +31,7 @@ class MidiInstDlg :public TQDialog {
   TQ_OBJECT
 	TQComboBox *box;
 public:
-	MidiInstDlg(TQWidget *tqparent);
+	MidiInstDlg(TQWidget *parent);
 	TQCString filename();
 public slots:
 	void help();
diff --git a/arts/tools/midimanagerview.cpp b/arts/tools/midimanagerview.cpp
index a9cefb07..3f137dea 100644
--- a/arts/tools/midimanagerview.cpp
+++ b/arts/tools/midimanagerview.cpp
@@ -78,7 +78,7 @@ public:
 class ConnectionWidget : public TQWidget {
 public:
 	MidiManagerView *v;
-	ConnectionWidget(MidiManagerView *v, TQWidget *tqparent) : TQWidget(tqparent), v(v)
+	ConnectionWidget(MidiManagerView *v, TQWidget *parent) : TQWidget(parent), v(v)
 	{
 	}
 	void paintEvent(TQPaintEvent * /*event*/)
diff --git a/arts/tools/midiportdlg.cpp b/arts/tools/midiportdlg.cpp
index eaed97f1..1c46d9e5 100644
--- a/arts/tools/midiportdlg.cpp
+++ b/arts/tools/midiportdlg.cpp
@@ -32,7 +32,7 @@
 #include <tqpushbutton.h>
 #include <kstdguiitem.h>
 
-MidiPortDlg::MidiPortDlg(TQWidget *tqparent, const char *oldname, const char *title) :TQDialog(tqparent,title,TRUE)
+MidiPortDlg::MidiPortDlg(TQWidget *parent, const char *oldname, const char *title) :TQDialog(parent,title,TRUE)
 {
 	TQVBoxLayout *maintqlayout = new TQVBoxLayout(this);
 
diff --git a/arts/tools/midiportdlg.h b/arts/tools/midiportdlg.h
index b6b428bc..59cb4f0f 100644
--- a/arts/tools/midiportdlg.h
+++ b/arts/tools/midiportdlg.h
@@ -34,7 +34,7 @@ class MidiPortDlg :public TQDialog {
   TQ_OBJECT
 	TQLineEdit *edit;
 public:
-	MidiPortDlg(TQWidget *tqparent, const char *device, const char *title);
+	MidiPortDlg(TQWidget *parent, const char *device, const char *title);
 	const char *device();
 
 public slots:
diff --git a/arts/tools/statusview.cpp b/arts/tools/statusview.cpp
index 6a9f0a25..901362fd 100644
--- a/arts/tools/statusview.cpp
+++ b/arts/tools/statusview.cpp
@@ -33,8 +33,8 @@
 using namespace std;
 using namespace Arts;
 
-ArtsStatusView::ArtsStatusView(Arts::SoundServer a_server, TQWidget* tqparent, const char* name )
-	: Template_ArtsView( tqparent,name )
+ArtsStatusView::ArtsStatusView(Arts::SoundServer a_server, TQWidget* parent, const char* name )
+	: Template_ArtsView( parent,name )
 	, server(a_server)
 {
 	this->setCaption( i18n( "aRts tqStatus" ) );
diff --git a/arts/tools/templateview.cpp b/arts/tools/templateview.cpp
index a89efac4..a589ff46 100644
--- a/arts/tools/templateview.cpp
+++ b/arts/tools/templateview.cpp
@@ -22,7 +22,7 @@
 
 //#include <kdebug.h>
 
-Template_ArtsView::Template_ArtsView( TQWidget* tqparent, const char* name ) : TQFrame( tqparent,name ){
+Template_ArtsView::Template_ArtsView( TQWidget* parent, const char* name ) : TQFrame( parent,name ){
 	//kdDebug()<<k_funcinfo<<endl;
 }
 
diff --git a/arts/gui/kde/kartswidget.h b/arts/gui/kde/kartswidget.h
index 7e745bf6..df46ae3b 100644
--- a/arts/gui/kde/kartswidget.h
+++ b/arts/gui/kde/kartswidget.h
@@ -40,7 +40,7 @@ class KArtsWidgetPrivate;
  *    tqlayout->addWidget(w);
  * </pre>
  *
  * In line 2 of the code, the "this" is the tqparent widget (which is usually
  * this in TQt code).
  *
  * The KArtsWidget class keeps a reference to the content widget, so the
@@ -57,12 +57,12 @@ public:
 	/**
 	 * creates a new KArtsWidget
 	 */
-	KArtsWidget( TQWidget* tqparent, const char* name );
+	KArtsWidget( TQWidget* parent, const char* name );
 
 	/**
 	 * creates a new KArtsWidget and sets the content to an Arts::Widget
 	 */
-	KArtsWidget( Arts::Widget content, TQWidget* tqparent, const char* name );
+	KArtsWidget( Arts::Widget content, TQWidget* parent, const char* name );
 	
 	/**
 	 * creates a new KArtsWidget with WidgetFlags and content
@@ -40,7 +40,7 @@ class KArtsWidgetPrivate;
  * </pre>
  *
- * In line 2 of the code, the "this" is the tqparent widget (which is usually
+ * In line 2 of the code, the "this" is the parent widget (which is usually
  * this in TQt code).
  *
-- 
cgit v1.2.1